# Parts of this script are reproductions of code produced by Maria Waltmann (waltmann@cbs.mpg.de or waltmann_m@ukw.de)
# and are used here as a reproduction of their original analysis

# Preps ----
# Libraries
library(lme4)
library(lmerTest)
library(irr)
library(tidyverse)
library(extrafont) #, font_import() (if you want all the fonts on your system)
library(ggpubr)
library(boot)
library(ggeffects)
library(insight)
library(arm)
library(foreach)
library(doParallel)


# Housekeeping
rm(list=ls())

# set-up the parallel pool
parallel::detectCores()
n.cores <- parallel::detectCores() - 2
my.cluster <- parallel::makeCluster(
  n.cores, 
  type = "PSOCK"
)
doParallel::registerDoParallel(cl = my.cluster)

# Load the data
xdata=read.table(file="RL_data_Retest_R_wo.txt", header=T, sep=",")
ids <- unique(xdata$SubID)
ids <- ids[-62] # This line is in because index 62 has value ""

waltmann_bootstrap <- function(xdata, ids, n, iteration){
  library(lme4)
  library(lmerTest)
  library(irr)
  library(tidyverse)
  library(extrafont) #, font_import() (if you want all the fonts on your system)
  library(ggpubr)
  library(boot)
  library(ggeffects)
  library(insight)
  library(arm)
  # Set n for this iteration of the bootstrap and sample participants with replacement 
  n <- n
  iteration <- iteration
  sub_ids <- sample(ids, n, replace = TRUE)
  bootstrap_data <- data.frame(matrix(ncol=7,nrow=0, dimnames=list(NULL, c("SubID","Session","correct","stay","pfb","persev","RT"))))
  for (i in 1:n){
    tmp <- data.frame(matrix(ncol=7,nrow=0, dimnames=list(NULL, c("SubID","Session","correct","stay","pfb","persev","RT"))))
    tmp <- rbind(tmp, xdata[xdata$SubID == sub_ids[i],])
    tmp$SubID <- i
    bootstrap_data <- rbind(bootstrap_data, tmp)
  }
  xdata <- bootstrap_data
  #xdata <- xdata[xdata$SubID %in% sub_ids,] # Only for sampling without replacement 
  
  
  # Tell R what to count as NA
  is.nan.data.frame <- function(x) #turn NaNs to NAs 
    do.call(cbind, lapply(x, is.nan))
  xdata[is.nan(xdata)] <- NA      # Matlab NaNs to NAs
  xdata[xdata==""] <- NA          # Empty cells to NAs
  # xdata$pfb<-factor(xdata$pfb) <-- leave PF effect coded
  xdata$Session<-factor(xdata$Session)
  xdata$persev<-factor(xdata$persev)
  
  # Even and odd trial datasets
  xdata_odd<-xdata[seq(1,nrow(xdata),2),]
  xdata_even<-xdata[seq(2,nrow(xdata),2),]
  
  # Models ----
  ## Accuracy ----
  ### Setup ----
  mean_acc1<-vector();mean_acc2<-vector();
  for (i in {unique(xdata$SubID)}){
    mean_acc1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i), ]$correct, na.rm=T)
    mean_acc2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i), ]$correct, na.rm=T)
  };
  
  ### Between session correlation and ICCs ----
  r_macc <- cor.test(mean_acc1,mean_acc2)
  icca1_macc <- icc(cbind(mean_acc1,mean_acc2), model="twoway", type="agreement",unit="single")
  icc1_macc <- icc(cbind(mean_acc1,mean_acc2), model="oneway", type="consistency",unit="single")
  
  ### Separate sessions ----
  
  #### S1 - Mixed logistic regression ----
  m_ac_s1 = glmer(correct ~ 1 + (1|SubID),
                  data = xdata[which(xdata$Session==1), ],
                  family = binomial,
                  control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                  na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_ac_s1, terms=c("SubID[all]"), type="re")
  s_acc1 = temp$predicted
  s_acc1_se = as.vector(unlist(se.ranef(m_ac_s1)))
  
  #### S2 - Mixed logistic regression ----
  m_ac_s2 = glmer(correct ~ 1 + (1|SubID),
                  data = xdata[which(xdata$Session==2), ],
                  family = binomial,
                  control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                  na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_ac_s2, terms=c("SubID[all]"), type="re")
  s_acc2 = temp$predicted
  s_acc2_se = as.vector(unlist(se.ranef(m_ac_s2)))
  
  ### Joint sessions ----
  #### Mixed logistic regression ----
  m_ac = glmer(correct ~ 1 + (1|SubID/Session),
               data = xdata,
               family = binomial,
               control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
               na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_ac, terms=c("SubID[all]", "Session"), type="re")
  acc1 = temp[temp$group==1,]$predicted
  acc2 = temp[temp$group==2,]$predicted
  acc1_se = as.vector(unlist(se.ranef(m_ac)[1])[1:n] +
                        unlist(se.ranef(m_ac)[2]))
  acc2_se = as.vector(unlist(se.ranef(m_ac)[1])[(n+1):(n*2)] +
                        unlist(se.ranef(m_ac)[2]))
  
  
  ### Split half ----
  
  #### Session 1 ----
  ##### Mixed logistic regression - Odds ----
  m_ac_odd_1 = glmer(correct ~ 1 + (1|SubID),
                     data = xdata_odd[which(xdata_odd$Session==1), ],
                     family = binomial,
                     control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                     na.action = na.exclude)
  ##### Mixed logistic regression - Evens ----
  m_ac_even_1 = glmer(correct ~ 1 + (1|SubID),
                      data = xdata_even[which(xdata_odd$Session==1), ],
                      family = binomial,
                      control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                      na.action = na.exclude)
  
  #### Session 2 ----
  ##### Mixed logistic regression - Odds ----
  m_ac_odd_2 = glmer(correct ~ 1 + (1|SubID),
                     data = xdata_odd[which(xdata_odd$Session==2), ],
                     family = binomial,
                     control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                     na.action = na.exclude)
  ##### Mixed logistic regression - Evens ----
  m_ac_even_2 = glmer(correct ~ 1 + (1|SubID),
                      data = xdata_even[which(xdata_odd$Session==2), ],
                      family = binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                      na.action = na.exclude)
  
  #### Predicted values ----
  acc_odd1 = as.vector(t(inv.logit(coef(m_ac_odd_1)$SubID[,"(Intercept)"])))
  acc_even1 = as.vector(t(inv.logit(coef(m_ac_even_1)$SubID[,"(Intercept)"])))
  acc_odd2 = as.vector(t(inv.logit(coef(m_ac_odd_2)$SubID[,"(Intercept)"])))
  acc_even2 = as.vector(t(inv.logit(coef(m_ac_even_2)$SubID[,"(Intercept)"])))
  
  
  ## Perseveration----
  
  ### Setup ----
  mean_per1<-vector();mean_per2<-vector();
  for (i in {unique(xdata$SubID)}){
    mean_per1[i] = mean(as.numeric(xdata[which(xdata$Session==1 & xdata$SubID==i), ]$persev)-1, na.rm=T)
    mean_per2[i] = mean(as.numeric(xdata[which(xdata$Session==2 & xdata$SubID==i), ]$persev)-1, na.rm=T)
  };
  
  ### Between session correlations and ICCs ----
  r_mper <- cor.test(mean_per1,mean_per2)
  icca1_mper <- icc(cbind(mean_per1,mean_per2), model="twoway", type="agreement",unit="single")
  icc1_mper <- icc(cbind(mean_per1,mean_per2), model="oneway", type="consistency",unit="single")
  
  #### S1 - Mixed logistic regression ----
  m_per_s1 = glmer(persev ~ 1 + (1|SubID),
                   data = xdata[which(xdata$Session==1), ],
                   family = binomial,
                   control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                   na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_per_s1, terms=c("SubID[all]"), type="re")
  s_per1 = temp$predicted
  s_per1_se = as.vector(unlist(se.ranef(m_per_s1)))
  
  #### S2 - Mixed logistic regression ----
  m_per_s2 = glmer(persev ~ 1 + (1|SubID),
                   data = xdata[which(xdata$Session==2), ],
                   family = binomial,
                   control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                   na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_per_s2, terms=c("SubID[all]"), type="re")
  s_per2 = temp$predicted
  s_per2_se = as.vector(unlist(se.ranef(m_per_s2)))
  
  ### Separate sessions ----
  
  ### Joint sessions ----
  #### Mixed logistic regression ----
  m_per = glmer(persev ~ 1 + (1|SubID/Session),
                data = xdata,
                family = binomial,
                control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_per, terms=c("SubID[all]", "Session"), type="re")
  per1 = temp[temp$group==1,]$predicted
  per2 = temp[temp$group==2,]$predicted
  per1_se = as.vector(unlist(se.ranef(m_per)[1])[1:n] +
                        unlist(se.ranef(m_per)[2]))
  per2_se = as.vector(unlist(se.ranef(m_per)[1])[(n+1):(n*2)] +
                        unlist(se.ranef(m_per)[2]))
  
  
  
  ### Split half ----
  #### Session 1 ----
  ##### Mixed logistic regression - Odds ----
  m_per_odd_1 = glmer(persev ~ 1 + (1|SubID),
                      data = xdata_odd[which(xdata_odd$Session==1), ],
                      family = binomial,
                      control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                      na.action = na.exclude)
  ##### Mixed logistic regression - Evens ----
  m_per_even_1 = glmer(persev ~ 1 + (1|SubID),
                       data = xdata_even[which(xdata_odd$Session==1), ],
                       family = binomial,
                       control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                       na.action = na.exclude)
  #### Session 2 ----
  ##### Mixed logistic regression - Odds ----
  m_per_odd_2 = glmer(persev ~ 1 + (1|SubID),
                      data = xdata_odd[which(xdata_odd$Session==2), ],
                      family = binomial,
                      control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                      na.action = na.exclude)
  ##### Mixed logistic regression - Evens ----
  m_per_even_2 = glmer(persev ~ 1 + (1|SubID),
                       data = xdata_even[which(xdata_odd$Session==2), ],
                       family = binomial,
                       control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                       na.action = na.exclude)
  
  #### Predicted values ----
  per_odd1 = as.vector(t(inv.logit(coef(m_ac_odd_1)$SubID[,"(Intercept)"])))
  per_even1 = as.vector(t(inv.logit(coef(m_ac_even_1)$SubID[,"(Intercept)"])))
  per_odd2 = as.vector(t(inv.logit(coef(m_ac_odd_2)$SubID[,"(Intercept)"])))
  per_even2 = as.vector(t(inv.logit(coef(m_ac_even_2)$SubID[,"(Intercept)"])))
  
  
  ## Switching----
  
  ### Setup ----
  mean_stay1<-vector();mean_stay2<-vector();mean_stayp1<-vector();mean_stayp2<-vector();mean_stayn1<-vector();mean_stayn2<-vector();
  for (i in {unique(xdata$SubID)}){
    mean_stay1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i), ]$stay, na.rm=T)
    mean_stay2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i), ]$stay, na.rm=T)
    mean_stayp1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i & xdata$pfb==1), ]$stay, na.rm=T)
    mean_stayp2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i & xdata$pfb==1), ]$stay, na.rm=T)
    mean_stayn1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i & xdata$pfb==-1), ]$stay, na.rm=T)
    mean_stayn2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i & xdata$pfb==-1), ]$stay, na.rm=T)
  };
  
  ### Between session correlations and ICCs ----
  
  # All
  r_mstay <- cor.test(mean_stay1,mean_stay2)
  icca1_mstay <- icc(cbind(mean_stay1,mean_stay2), model="twoway", type="agreement",unit="single")
  icc1_mstay <- icc(cbind(mean_stay1,mean_stay2), model="oneway", type="consistency",unit="single")
  
  # Positive feedback
  r_mstayp <- cor.test(mean_stayp1,mean_stayp2)
  icca1_mstayp <- icc(cbind(mean_stayp1,mean_stayp2), model="twoway", type="agreement",unit="single")
  icc1_mstayp <- icc(cbind(mean_stayp1,mean_stayp2), model="oneway", type="consistency",unit="single")
  
  # Negative feedback
  r_mstayn <- cor.test(mean_stayn1,mean_stayn2)
  icca1_mstayn <- icc(cbind(mean_stayn1,mean_stayn2), model="twoway", type="agreement",unit="single")
  icc1_mstayn <- icc(cbind(mean_stayn1,mean_stayn2), model="oneway", type="consistency",unit="single")
  
  ### Separate Sessions ----
  #### S1 Overall - Mixed logistic regression ----
  m_sw_s1 = glmer(stay ~ 1 + pfb + (1+pfb|SubID),
                  data = xdata[which(xdata$Session==1), ],
                  family = binomial,
                  control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                  na.action = na.exclude)
  # predicted values & standard errors
  s_stay1 = as.vector(t(inv.logit(coef(m_sw_s1)$SubID[,"(Intercept)"])))
  s_stay1_se = as.vector(unlist(se.ranef(m_sw_s1))[1:n])
  
  #### S2 Overall - Mixed logistic regression ----
  m_sw_s2 = glmer(stay ~ 1 + pfb + (1+pfb|SubID),
                  data = xdata[which(xdata$Session==2), ],
                  family = binomial,
                  control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                  na.action = na.exclude)
  # predicted values & standard errors
  s_stay2 = as.vector(t(inv.logit(coef(m_sw_s2)$SubID[,"(Intercept)"])))
  s_stay2_se = as.vector(unlist(se.ranef(m_sw_s2))[1:n])
  
  #### S1 After Loss - Mixed logistic regression ----
  # previous feedback as factor in order to get "simple effects" of staying after losses/wins for model-calculated ICC(1)
  m_sw_l_s1 = glmer(stay ~ as.factor(pfb) + (1+as.factor(pfb)|SubID),
                    data = xdata[which(xdata$Session==1), ],
                    family = binomial,
                    control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                    na.action = na.exclude) #mixed logistic regression
  # predicted values & standard errors
  s_stayn1 = as.vector(t(inv.logit(coef(m_sw_l_s1)$SubID[,"(Intercept)"])))
  s_stayn1_se = as.vector(unlist(se.ranef(m_sw_l_s1))[1:n])
  
  #### S1 After Win - Mixed logistic regression ----
  m_sw_w_s1 = glmer(stay ~ relevel(as.factor(pfb),"1") + (1 + relevel(as.factor(pfb),"1")|SubID),
                    data = xdata[which(xdata$Session==1), ],
                    family = binomial,
                    control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                    na.action = na.exclude)
  # predicted values & standard errors
  s_stayp1 = as.vector(t(inv.logit(coef(m_sw_w_s1)$SubID[,"(Intercept)"])))
  s_stayp1_se = as.vector(unlist(se.ranef(m_sw_w_s1))[1:n])
  
  #### S2 After Loss - Mixed logistic regression ----
  m_sw_l_s2 = glmer(stay ~ as.factor(pfb) + (1+as.factor(pfb)|SubID),
                    data = xdata[which(xdata$Session==2), ],
                    family = binomial,
                    control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                    na.action = na.exclude)
  # predicted values & standard errors
  s_stayn2 = as.vector(t(inv.logit(coef(m_sw_l_s2)$SubID[,"(Intercept)"])))
  s_stayn2_se = as.vector(unlist(se.ranef(m_sw_l_s2))[1:n])
  
  #### S2 After Win - Mixed logistic regression ----
  m_sw_w_s2 = glmer(stay ~ relevel(as.factor(pfb),"1") + (1 + relevel(as.factor(pfb),"1")|SubID),
                    data = xdata[which(xdata$Session==2), ],
                    family = binomial,
                    control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                    na.action = na.exclude)
  # predicted values & standard errors
  s_stayp2 = as.vector(t(inv.logit(coef(m_sw_w_s2)$SubID[,"(Intercept)"])))
  s_stayp2_se = as.vector(unlist(se.ranef(m_sw_w_s2))[1:n])
  
  ### Joint Sessions ----
  #### Overall - Mixed logistic regression ----
  m_sw = glmer(stay ~ pfb + (1 + pfb|SubID/Session),
               data = xdata,
               family = binomial,
               control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
               na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_sw, terms=c("SubID[all]", "Session"), type="re")
  stay1 = temp[temp$group==1,]$predicted
  stay2 = temp[temp$group==2,]$predicted
  stay1_se = as.vector(unlist(se.ranef(m_sw)[1])[1:n] +
                         unlist(se.ranef(m_sw)[2])[1:n])
  stay2_se = as.vector(unlist(se.ranef(m_sw)[1])[(n+1):(n*2)] +
                         unlist(se.ranef(m_sw)[2])[1:n])
  #### After Loss - Mixed logistic regression ----
  # previous feedback as factor in order to get "simple effects" of staying after losses/wins for model-calculated ICC(1)
  m_sw_l = glmer(stay ~ as.factor(pfb) + (1 + as.factor(pfb)|SubID/Session),
                 data = xdata,
                 family = binomial,
                 control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                 na.action = na.exclude)
  # predicted values & standard errors
  temp <- ggpredict(m_sw_l, terms=c("SubID[all]", "Session", "pfb"), type="re")
  stayn1 = temp[temp$group==1 & temp$facet==-1,]$predicted
  stayn2 = temp[temp$group==2 & temp$facet==-1,]$predicted
  stayn1_se = as.vector(unlist(se.ranef(m_sw_l)[1])[1:n] +
                          unlist(se.ranef(m_sw_l)[2])[1:n])
  stayn2_se = as.vector(unlist(se.ranef(m_sw_l)[1])[(n+1):(n*2)] +
                          unlist(se.ranef(m_sw_l)[2])[1:n])
  
  #### After Win - Mixed logistic regression ----
  m_sw_w = glmer(stay ~ relevel(as.factor(pfb),"1") + (1 + relevel(as.factor(pfb),"1")|SubID/Session),
                 data = xdata,
                 family = binomial,
                 control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  # predicted values & standard errors
  temp <- ggpredict(m_sw_w, terms=c("SubID[all]", "Session", "pfb"), type="re")
  stayp1 = temp[temp$group==1 & temp$facet==1,]$predicted
  stayp2 = temp[temp$group==2 & temp$facet==1,]$predicted
  stayp1_se = as.vector(unlist(se.ranef(m_sw_w)[1])[1:n] +
                          unlist(se.ranef(m_sw_w)[2])[1:n])
  stayp2_se = as.vector(unlist(se.ranef(m_sw_w)[1])[(n+1):(n*2)] +
                          unlist(se.ranef(m_sw_w)[2])[1:n])
  
  
  ### Split half ----
  #### Session 1 ----
  ##### Mixed logistic regression - Odds ----
  m_sw_odd_1 = glmer(stay ~ 1 + pfb + (1 + pfb|SubID),
                     data = xdata_odd[which(xdata_odd$Session==1), ],
                     family = binomial,
                     control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                     na.action = na.exclude)
  
  ##### Mixed logistic regression - Evens ----
  m_sw_even_1 = glmer(stay ~ 1 + pfb + (1 + pfb|SubID),
                      data = xdata_even[which(xdata_even$Session==1), ],
                      family = binomial,
                      control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                      na.action = na.exclude)
  
  #### Session 2 ----
  ##### Mixed logistic regression - Odds ----
  m_sw_odd_2 = glmer(stay ~ 1 + pfb + (1 + pfb|SubID),
                     data = xdata_odd[which(xdata_odd$Session==2), ],
                     family = binomial,
                     control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                     na.action = na.exclude)
  
  ##### Mixed logistic regression - Evens ----
  m_sw_even_2 = glmer(stay ~ 1 + pfb + (1 + pfb|SubID),
                      data = xdata_even[which(xdata_even$Session==2), ],
                      family = binomial,
                      control = glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
                      na.action = na.exclude)
  
  #### Predicted values ----
  stay_odd1 = as.vector(t(inv.logit(coef(m_sw_odd_1)$SubID[,"(Intercept)"])))
  stay_even1 = as.vector(t(inv.logit(coef(m_sw_even_1)$SubID[,"(Intercept)"])))
  stayp_odd1 = as.vector(t(inv.logit(coef(m_sw_odd_1)$SubID[,"(Intercept)"] +
                                       coef(m_sw_odd_1)$SubID[,"pfb"])))
  stayp_even1 = as.vector(t(inv.logit(coef(m_sw_even_1)$SubID[,"(Intercept)"] +
                                        coef(m_sw_even_1)$SubID[,"pfb"])))
  stayn_odd1 = as.vector(t(inv.logit(coef(m_sw_odd_1)$SubID[,"(Intercept)"] -
                                       coef(m_sw_odd_1)$SubID[,"pfb"])))
  stayn_even1 = as.vector(t(inv.logit(coef(m_sw_even_1)$SubID[,"(Intercept)"] -
                                        coef(m_sw_even_1)$SubID[,"pfb"])))
      
  ## RT ----
  
  ### Setup ----    
  # Prep empty vectors
  mean_RT1<-vector(); mean_RT2<-vector(); mean_RTp1<-vector(); mean_RTp2<-vector();
  mean_RTn1<-vector();mean_RTn2<-vector();  mean_deltaRT1<-vector();mean_deltaRT2<-vector();
  
  # Get mean RTs for each participant, session, etc
  for (i in {unique(xdata$SubID)}){
    
    # Overall per session mean
    mean_RT1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i), ]$RT, na.rm=T)
    mean_RT2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i), ]$RT, na.rm=T)
    
    # Per session mean for trials when positive feedback received
    mean_RTp1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i & xdata$pfb==1), ]$RT, na.rm=T)
    mean_RTp2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i & xdata$pfb==1), ]$RT, na.rm=T)
    
    # Per session mean for trials when negative feedback received
    mean_RTn1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i & xdata$pfb==-1), ]$RT, na.rm=T)
    mean_RTn2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i & xdata$pfb==-1), ]$RT, na.rm=T)
  
    # Per session mean diff for positive vs negative feedback
    mean_deltaRT1[i] = mean(xdata[which(xdata$Session==1 & xdata$SubID==i & xdata$pfb==1), ]$RT, na.rm=T) -
      mean(xdata[which(xdata$Session==1 & xdata$SubID==i & xdata$pfb==-1), ]$RT, na.rm=T)    
    mean_deltaRT2[i] = mean(xdata[which(xdata$Session==2 & xdata$SubID==i & xdata$pfb==1), ]$RT, na.rm=T)-
      mean(xdata[which(xdata$Session==2 & xdata$SubID==i & xdata$pfb==-1), ]$RT, na.rm=T)
  };
  
  ### Between session correlations and ICCs ----
  r_mRT <- cor.test(mean_RT1,mean_RT2)
  icca1_mRT <- icc(cbind(mean_RT1,mean_RT2), model="twoway", type="agreement",unit="single")
  icc1_mRT <- icc(cbind(mean_RT1,mean_RT2), model="oneway", type="consistency",unit="single")
  
  r_mRTp <- cor.test(mean_RTp1,mean_RTp2)
  icca1_mRTp <- icc(cbind(mean_RTp1,mean_RTp2), model="twoway", type="agreement",unit="single")
  icc1_mRTp <- icc(cbind(mean_RTp1,mean_RTp2), model="oneway", type="consistency",unit="single")
  
  r_mRTn <- cor.test(mean_RTn1,mean_RTn2)
  icca1_mRTn <- icc(cbind(mean_RTn1,mean_RTn2), model="twoway", type="agreement",unit="single")
  icc1_mRTn <- icc(cbind(mean_RTn1,mean_RTn2), model="oneway", type="consistency",unit="single")
  
  r_mdeltaRT <- cor.test(mean_deltaRT1,mean_deltaRT2)
  icca1_mdeltaRT <- icc(cbind(mean_deltaRT1,mean_deltaRT2), model="twoway", type="agreement",unit="single")
  icc1_mdeltaRT <- icc(cbind(mean_deltaRT1,mean_deltaRT2), model="oneway", type="consistency",unit="single")
      
  ### Separate sessions ----
  #### Overall ----
  ##### S1 - Mixed linear regression ----
  m_RT_s1 = lmer(RT ~ pfb + (1 + pfb|SubID),
                 data = xdata[which(xdata$Session==1), ],
                 na.action = na.exclude,
                 control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  
  # predicted values & standard errors
  s_RT1 = as.vector(t( coef(m_RT_s1)$SubID[,"(Intercept)"] ))
  s_RT1_se = as.vector(unlist( se.ranef(m_RT_s1) )[1:n])
  s_delta_RT1_se = as.vector(unlist( se.ranef(m_RT_s1) )[(n+1):(n*2)])
  temp <- ggpredict(m_RT_s1, terms=c("SubID[all]", "pfb"), type="re")
  s_delta_RT1 = temp[temp$group==1, ]$predicted - temp[temp$group==-1, ]$predicted
  
  ##### S2 - Mixed linear regression ----
  m_RT_s2 = lmer(RT ~ pfb + (1 + pfb|SubID),
                 data = xdata[which(xdata$Session==2), ],
                 na.action = na.exclude,
                 control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  
  # predicted values & standard errors
  s_RT2 = as.vector(t( coef(m_RT_s2)$SubID[,"(Intercept)"] ))
  s_RT2_se = as.vector( unlist(se.ranef(m_RT_s2))[1:n] )
  s_delta_RT2_se = as.vector( unlist(se.ranef(m_RT_s2))[(n+1):(n*2)] )
  temp <- ggpredict(m_RT_s2, terms=c("SubID[all]", "pfb"), type="re")
  s_delta_RT2 = temp[temp$group==1, ]$predicted - temp[temp$group==-1, ]$predicted
  
  #### Losses ----
  
  # previous feedback as factor in order to get "simple effects" of staying after losses/wins for standard errors
  
  ##### S1 - Mixed linear regression ----
  m_RT_l_s1 = lmer(RT ~ as.factor(pfb) + (1 + as.factor(pfb)|SubID),
                   data=xdata[which(xdata$Session==1), ],
                   na.action = na.exclude,
                   control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  # predicted values & standard errors
  s_RTn1 = as.vector(t(coef(m_RT_l_s1)$SubID[,"(Intercept)"]))
  s_RTn1_se = as.vector(unlist(se.ranef(m_RT_l_s1))[1:n])
        
  ##### S2 - Mixed linear regression ----
  m_RT_l_s2 = lmer(RT ~ as.factor(pfb) + (1 + as.factor(pfb)|SubID),
                   data=xdata[which(xdata$Session==2), ],
                   na.action = na.exclude,
                   control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  # predicted values & standard errors
  s_RTn2 = as.vector(t(coef(m_RT_l_s2)$SubID[,"(Intercept)"]))
  s_RTn2_se = as.vector(unlist(se.ranef(m_RT_l_s2))[1:n])
   
  
  #### Wins ----
  ##### S1 - Mixed linear regression ----
  m_RT_w_s1 = lmer(RT ~ relevel(as.factor(pfb),"1") + (1 + relevel(as.factor(pfb),"1")|SubID),
                   data = xdata[which(xdata$Session==1), ],
                   na.action = na.exclude,
                   control = lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) 
  # predicted values & standard errors
  s_RTp1 = as.vector(t(coef(m_RT_w_s1)$SubID[,"(Intercept)"]))
  s_RTp1_se = as.vector(unlist(se.ranef(m_RT_w_s1))[1:n])
        
  ##### S2 - Mixed linear regression ----
  m_RT_w_s2 = lmer(RT ~ relevel(as.factor(pfb),"1") + (1 + relevel(as.factor(pfb),"1")|SubID),
                   data=xdata[which(xdata$Session==2), ],
                   na.action = na.exclude,
                   control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  # predicted values & standard errors
  s_RTp2 = as.vector(t(coef(m_RT_w_s2)$SubID[,"(Intercept)"]))
  s_RTp2_se = as.vector(unlist(se.ranef(m_RT_w_s2))[1:n])
  
  
  ### Joint Sessions ----
  
  #### Overall - Mixed linear regression ----
  m_RT = lmer(RT ~ pfb + (1+pfb|SubID/Session),
              data = xdata,
              na.action = na.exclude,
              control = lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  # predicted values & standard errors
  temp <- ggpredict(m_RT, terms=c("SubID[all]", "Session"), type="re")
  RT1 = temp[temp$group==1, ]$predicted
  RT2 = temp[temp$group==2, ]$predicted
  
  RT1_se = as.vector(unlist(se.ranef(m_RT)[1])[1:n] + 
                       unlist(se.ranef(m_RT)[2])[1:n])
  
  #' *Is this okay?*
  delta_RT1_se = as.vector(unlist(se.ranef(m_RT)[1])[1:n] + 
                             unlist(se.ranef(m_RT)[2])[(n+1):(n*2)])
  
  RT2_se = as.vector(unlist(se.ranef(m_RT)[1])[(n+1):(n*2)] + 
                       unlist(se.ranef(m_RT)[2])[1:n])
  delta_RT2_se = as.vector(unlist(se.ranef(m_RT)[1])[1:n] + 
                             unlist(se.ranef(m_RT)[2])[(n+1):(n*2)])
  
  temp <- ggpredict(m_RT, terms=c("SubID[all]", "Session", "pfb"), type="re")
  delta_RT1 = temp[temp$group==1 & temp$facet==1, ]$predicted - temp[temp$group==1 & temp$facet==-1, ]$predicted
  delta_RT2 = temp[temp$group==2 & temp$facet==1, ]$predicted - temp[temp$group==2 & temp$facet==-1, ]$predicted
  
  #### Losses - Mixed linear regression ----
  m_RT_l = lmer(RT ~ as.factor(pfb) + (1 + as.factor(pfb)|SubID/Session),
                data = xdata,
                na.action = na.exclude,
                control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  # predicted values & standard errors
  temp <- ggpredict(m_RT_l, terms=c("SubID[all]", "Session", "pfb"), type="re")
  RTn1 = temp[temp$group==1 & temp$facet==-1,]$predicted
  RTn2 = temp[temp$group==2 & temp$facet==-1,]$predicted
  RTn1_se = as.vector(unlist(se.ranef(m_RT_l)[1])[1:n] + 
                        unlist(se.ranef(m_RT_l)[2])[1:n])
  RTn2_se = as.vector(unlist(se.ranef(m_RT_l)[1])[(n+1):(n*2)] + 
                        unlist(se.ranef(m_RT_l)[2])[1:n])
  
  xdata2 <- xdata
  xdata2$pfb <- relevel(as.factor(xdata2$pfb), "1")
  
  #### Wins - Mixed linear regression ----
  m_RT_w = lmer(RT ~ pfb + (1 + pfb | SubID/Session),
                data = xdata2,
                na.action = na.exclude,
                control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  # predicted values & standard errors
  temp <- ggpredict(m_RT_w, terms=c("SubID[all]", "Session", "pfb"), type="re")
  RTp1 = temp[temp$group==1 & temp$facet==1,]$predicted
  RTp2 = temp[temp$group==2 & temp$facet==1,]$predicted
  RTp1_se = as.vector(unlist(se.ranef(m_RT_w)[1])[1:n] + 
                        unlist(se.ranef(m_RT_w)[2])[1:n])
  RTp2_se = as.vector(unlist(se.ranef(m_RT_w)[1])[(n+1):(n*2)] + 
                        unlist(se.ranef(m_RT_w)[2])[1:n])
  
    
  ### Split half ---- 
  #### Session 1 ----
  ##### Mixed linear regression - Odds ----
  m_RT_odd_1 = lmer(RT ~ pfb + (1 + pfb|SubID),
                    data=xdata_odd[which(xdata_odd$Session==1), ],
                    na.action = na.exclude,
                    control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))
  
  ##### Mixed linear regression - Evens ----
  m_RT_even_1 = lmer(RT ~ pfb + (1 + pfb|SubID),
                     data=xdata_even[which(xdata_even$Session==1), ],
                     na.action = na.exclude,
                     control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
  #### Session 2 ----
  ##### Mixed linear regression - Odds ----
  m_RT_odd_2 = lmer(RT ~ pfb + (1 + pfb|SubID),
                    data=xdata_odd[which(xdata_odd$Session==2), ],
                    na.action = na.exclude,
                    control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
  
  ##### Mixed linear regression - Evens ----
  m_RT_even_2 = lmer(RT ~ pfb + (1 + pfb|SubID),
                     data=xdata_even[which(xdata_even$Session==2), ],
                     na.action = na.exclude,
                     control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
  
  #### Predicted values ----
  RT_odd1 = as.vector(t( coef(m_RT_odd_1)$SubID[,"(Intercept)"] ))
  RT_even1 = as.vector(t( coef(m_RT_even_1)$SubID[,"(Intercept)"] ))
  
  RTp_odd1 = as.vector(t( coef(m_RT_odd_1)$SubID[,"(Intercept)"] + 
                            coef(m_RT_odd_1)$SubID[,"pfb"] ))
  RTp_even1 = as.vector(t( coef(m_RT_even_1)$SubID[,"(Intercept)"] + 
                             coef(m_RT_even_1)$SubID[,"pfb"] ))
  
  RTn_odd1 = as.vector(t( coef(m_RT_odd_1)$SubID[,"(Intercept)"] - 
                            coef(m_RT_odd_1)$SubID[,"pfb"] ))
  RTn_even1 = as.vector(t( coef(m_RT_even_1)$SubID[,"(Intercept)"] - 
                             coef(m_RT_even_1)$SubID[,"pfb"] ))
  
  delta_RT_odd1 = RTp_odd1-RTn_odd1
  delta_RT_even1 = RTp_even1-RTn_even1
  
  
  ## Comparison of variance components ---- 
  
  # Make little plot to show changing variance components wrt ICC with estimation methods
  
  # For reference: Formula for ICC(A,1)
  # ICCA1<-(MSr - MSe)/(MSr + (nr - 1) * MSe +  (nr/ns) * (MSc - MSe)
  # ICC1<-(MSr-MSw)/(MSr+ (nr-1)*MSw)
  
  # Prep
  MSr<-vector()
  MSc<-vector()
  MSe<-vector()
  g<-vector()
  
  
  namesmean=matrix(c("mean_acc1", "mean_acc2",
                     "mean_per1", "mean_per2",
                     "mean_stay1", "mean_stay2",
                     "mean_stayp1", "mean_stayp2",
                     "mean_stayn1", "mean_stayn2",
                     "mean_RT1", "mean_RT2",
                     "mean_RTp1", "mean_RTp2",
                     "mean_RTn1", "mean_RTn2",
                     "mean_deltaRT1", "mean_deltaRT2"),
                   nrow=9, ncol=2, byrow=T)
  
  namessep=matrix(c("s_acc1", "s_acc2",
                    "s_per1", "s_per2",
                    "s_stay1", "s_stay2",
                    "s_stayp1", "s_stayp2",
                    "s_stayn1", "s_stayn2",
                    "s_RT1", "s_RT2",
                    "s_RTp1", "s_RTp2",
                    "s_RTn1", "s_RTn2",
                    "s_delta_RT1", "s_delta_RT2"),
                  nrow=9, ncol=2, byrow=T)
  
  namesjoint=matrix(c("acc1", "acc2",
                      "per1", "per2",
                      "stay1", "stay2",
                      "stayp1", "stayp2",
                      "stayn1", "stayn2",
                      "RT1", "RT2",
                      "RTp1", "RTp2",
                      "RTn1", "RTn2",
                      "delta_RT1", "delta_RT2"),
                    nrow=9, ncol=2, byrow=T)
  
  namesmodelc=c("m_ac","m_per","m_sw","m_sw_w","m_sw_l", "m_RT", "m_RT_w", "m_RT_l", "m_RT")
  
  namestitle=c("Accuracy", "Perseveration", "Stay behaviour overall", "Staying after wins", "Staying after losses",
               "Reaction times overall", "Reaction times after wins", "Reaction times after losses",
               "∆ reaction times")
  
  # j is the different graphs (Accuracy, Perseveration, etc)
  out_data <- data.frame(matrix(ncol=4,nrow=0, dimnames=list(NULL, c("model", "varcomp", "value", "variable"))))
  
  for (j in 1:9){
    # i is the different estimation methods (mean, separate models, joint model, Model calculated)?
    for (i in 1:4)
    {
      if (any(i==1:3)){
        
        # Bind data to ratings depending on different values of i and j 
        # 1 = mean
        if (i==1){ratings=cbind(eval(parse(text=namesmean[j,1])),eval(parse(text=namesmean[j,2])))}
        # 2 = separate
        else if (i==2){ratings=cbind(eval(parse(text=namessep[j,1])),eval(parse(text=namessep[j,2])))}
        # 3 = joint
        else {ratings=cbind(eval(parse(text=namesjoint[j,1])),eval(parse(text=namesjoint[j,2])))}
        
        # logit values for first 5 graphs
        if (any(j==1:5)){ratings<-logit(ratings)}
        
        ratings[!is.finite(ratings)]=NA #remove infinity vals
        ratings <- as.matrix(na.omit(ratings)) # remove NAs
        
        ns <- nrow(ratings) # Number of rows
        nr <- ncol(ratings) # Number of columns
        
        SStotal <- var(as.numeric(ratings)) * (ns * nr - 1)
        MSr[i] <- var(apply(ratings, 1, mean)) * nr # Between subs variance
        
        # Within subs variance - This appears to be calculated and discarded
        MSw <- sum(apply(ratings, 1, var)/ns)  
        
        MSc[i] <- var(apply(ratings, 2, mean)) * ns # Session variance
        MSe[i] <- (SStotal - MSr[i] * (ns - 1) - MSc[i] * (nr - 1))/((ns - 1) * (nr - 1)) #Error variance
      }
      else{ # 4 = Model calculated
        # icc(1) stuff here
        MSc[i]=0
        if (any(j==1:8)){
          MSe[i]=get_variance_intercept(eval(parse(text=namesmodelc[j])))[1]
          MSr[i]=get_variance_intercept(eval(parse(text=namesmodelc[j])))[2]}
        else {
          MSe[i]=get_variance_slope(eval(parse(text=namesmodelc[j])))[1]
          MSr[i]=get_variance_slope(eval(parse(text=namesmodelc[j])))[2]}
      }
    }
    
    x<-rowSums(cbind(MSr, MSc, MSe)) # Sum variance components
    value<-c(cbind(MSr, MSc, MSe)/x)   # Normalise (sum to 1)
    
    # Generate labels for the data frame below (y_data)
    varcomp<-c(rep("Between subject variance",4),rep("Within subject variance",4),rep("Error variance",4))
    model<-c(rep(c("Mean", "Separate Models", "Joint Model", "Model Calculated"),3))
    
    # Build data frame with:
    #   Col 1: different models 
    #   Col 2: different variance components
    #   Col 3: the actual values for the combinations of models and variance components
    ydata<-data.frame(model,varcomp,value)
    
    # Convert Cols 1 and 2 to factors
    ydata$model<-factor(ydata$model,levels = c("Mean","Separate Models","Joint Model","Model Calculated"))
    ydata$varcomp<-factor(ydata$varcomp,levels = c("Within subject variance","Error variance","Between subject variance"))
    ydata$variable <-  namestitle[j]
    out_data <- rbind(out_data, ydata)
  
  }
  
  
  out_data$variable <- factor(out_data$variable)
  out_data$variable <- as.numeric(out_data$variable)
  out_data$varcomp <- as.numeric(out_data$varcomp)
  out_data$model <- as.numeric(out_data$model)
  out_data$n <- n
  out_data$iteration <- iteration
  return(out_data)
}

#ns <- c(10,20,30,40,50,75,100,125,150,200,250,300,400,500,1000) # these will be the sample sizes we'll iterate through
ns <- c(125,150,200,250,300) # just to test the code :)
iterations <- 1000 # this will be the number of iterations for each sample size

#n <- 20 # used as placeholders for testing
#iteration <- 1 # used as placeholders for testing
start_time <- Sys.time()
for (i in ns){
  print(i)
  run_parallel <- foreach(
    ii = 1:iterations,
    .combine = rbind
  ) %dopar% {
    print(ii)
    tmp <- waltmann_bootstrap(xdata, ids, i, ii)
  }
  run_parallel
  write.csv(run_parallel, str_interp("bootstrap_n-${i}_iterations-${iterations}.csv"), row.names = FALSE)
}
end_time <- Sys.time()
end_time - start_time