### Script to analyse data from 2 sessions of the probabilistic reversal learning task using mixed effects models ###
### It compares joint and separate modeling of sessions in terms of the re-test reliability of the predicted ###
### values of those models and model calculated reliability and plots the results ### 

# Written by: Maria Waltmann (waltmann@cbs.mpg.de or waltmann_m@ukw.de)

# Preps ----
# Libraries
library(lme4)
library(lmerTest)
library(irr)
library(tidyverse)
library(extrafont) #, font_import() (if you want all the fonts on your system)
library(ggpubr)
library(boot)
library(ggeffects)
library(insight)
library(arm)


# Housekeeping
rm(list=ls())

# Load the data
xdata=read.table(file="RL_data_Retest_R_wo.txt", header=T, sep=",")

# Tell R what to count as NA
is.nan.data.frame <- function(x) #turn NaNs to NAs 
  do.call(cbind, lapply(x, is.nan))
xdata[is.nan(xdata)] <- NA      # Matlab NaNs to NAs
xdata[xdata==""] <- NA          # Empty cells to NAs
# xdata$pfb<-factor(xdata$pfb) <-- leave PF effect coded
xdata$Session<-factor(xdata$Session)
xdata$persev<-factor(xdata$persev)

# Even and odd trial datasets
xdata_odd<-xdata[seq(1,nrow(xdata),2),]
xdata_even<-xdata[seq(2,nrow(xdata),2),]


# Accuracy ----
## Means ----
mean_acc1<-vector();mean_acc2<-vector();
for (i in {unique(xdata$SubID)}){
  mean_acc1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i), ]$correct, na.rm=T)
  mean_acc2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i), ]$correct, na.rm=T)
};

r_macc<-cor.test(mean_acc1,mean_acc2)
icca1_macc<-icc(cbind(mean_acc1,mean_acc2), model="twoway", type="agreement",unit="single")
icc1_macc<-icc(cbind(mean_acc1,mean_acc2), model="oneway", type="consistency",unit="single")

# Sessions separately

# Session 1 - mixed logistic regression
m_ac_s1=glmer(correct~1+(1|SubID),
              data=xdata[which(xdata$Session==1), ],
              family=binomial,
              control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
              na.action = na.exclude)   
# predicted values & standard errors
temp<-ggpredict(m_ac_s1, terms=c("SubID[all]"), type="re")
s_acc1=temp$predicted
s_acc1_se=as.vector(unlist(se.ranef(m_ac_s1)))

# Session 2 - mixed logistic regression
m_ac_s2=glmer(correct~1+(1|SubID),
              data=xdata[which(xdata$Session==2), ],
              family=binomial,
              control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
              na.action = na.exclude)
# predicted values & standard errors
temp<-ggpredict(m_ac_s2, terms=c("SubID[all]"), type="re")
s_acc2=temp$predicted
s_acc2_se=as.vector(unlist(se.ranef(m_ac_s2)))

# Jointly
# Mixed logistic regression
m_ac=glmer(correct~1+(1|SubID/Session),
           data=xdata,
           family=binomial,
           control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)),
           na.action = na.exclude)
# predicted values & standard errors
temp<-ggpredict(m_ac, terms=c("SubID[all]", "Session"), type="re")
acc1=temp[temp$group==1,]$predicted
acc2=temp[temp$group==2,]$predicted
acc1_se=as.vector(unlist(se.ranef(m_ac)[1])[1:150]+unlist(se.ranef(m_ac)[2]))
acc2_se=as.vector(unlist(se.ranef(m_ac)[1])[151:300]+unlist(se.ranef(m_ac)[2]))

## ACC Plot ----

# Pull predicted values and SEs into single dataframe
data=data.frame(acc1,acc2,acc1_se,acc2_se,s_acc1,s_acc2,s_acc1_se,s_acc2_se)

ggplot(data=data)+
    geom_point(aes(s_acc1,s_acc2, size=(s_acc1_se+s_acc2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_acc1,s_acc2, color="lightgrey"))+
    geom_smooth(aes(s_acc1,s_acc2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(acc1,acc2, size=(acc1_se+acc2_se)/2,color='khaki'), alpha=0.2)+
    geom_point(aes(acc1,acc2,color='goldenrod1'))+
    geom_smooth(aes(acc1,acc2),color='goldenrod1',method=lm,se=F)+
    labs(title = "Accuracy", x="Accuracy T1", y="Accuracy T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "goldenrod1", "khaki"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_acc1,s_acc2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_acc1,s_acc2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_acc1,s_acc2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_acc1,s_acc2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_acc1,s_acc2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_acc1,s_acc2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_acc1, s_acc2)$estimate,2),"[",round(cor.test(s_acc1, s_acc2)$conf.int[1],2),
                                           "-",round(cor.test(s_acc1, s_acc2)$conf.int[2],2),"]",
                                            sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(acc1,acc2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(acc1,acc2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(acc1,acc2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(acc1,acc2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(acc1,acc2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(acc1,acc2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(acc1, acc2)$estimate,2),"[",round(cor.test(acc1, acc2)$conf.int[1],2),
                                           "-",round(cor.test(acc1, acc2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_intercept(m_ac)[2]/
                                                   (get_variance_intercept(m_ac)[2]+
                                                      (get_variance_intercept(m_ac)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)

ggsave(filename = "figures/Behavioural/WO/accuracy_r.png", width = 4.5, height = 4.5, units = 'in')
    
  
  # Split half
  m_ac_odd_1=glmer(correct~1+(1|SubID), data=xdata_odd[which(xdata_odd$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  m_ac_even_1=glmer(correct~1+(1|SubID), data=xdata_even[which(xdata_odd$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  m_ac_odd_2=glmer(correct~1+(1|SubID), data=xdata_odd[which(xdata_odd$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  m_ac_even_2=glmer(correct~1+(1|SubID), data=xdata_even[which(xdata_odd$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  
    #predicted values
    data=data.frame(acc_odd1=as.vector(t(inv.logit(coef(m_ac_odd_1)$SubID[,"(Intercept)"]))),
                  acc_even1=as.vector(t(inv.logit(coef(m_ac_even_1)$SubID[,"(Intercept)"]))),
                  acc_odd2=as.vector(t(inv.logit(coef(m_ac_odd_2)$SubID[,"(Intercept)"]))),
                  acc_even2=as.vector(t(inv.logit(coef(m_ac_even_2)$SubID[,"(Intercept)"]))))
    
    #plot
    ggplot(data=data,aes(acc_odd2,acc_even2,color='goldenrod1'))+
      geom_point(color='goldenrod1')+
      geom_smooth(method=lm,se=F)+
      labs(title = "Accuracy", x="Accuracy Odd Trials", y="Accuracy Even Trials")+
      theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
            panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
            legend.position = c(0.25, 0.95),legend.background=element_blank())+
      scale_color_identity(name="",breaks = "goldenrod1",
                           labels = paste("r=",round(cor.test(data$acc_odd2, data$acc_even2)$estimate,digits=2), "[",round(cor.test(data$acc_odd2, data$acc_even2)$conf.int[1],digits=2), "-",
                                          round(cor.test(data$acc_odd2, data$acc_even2)$conf.int[2],digits=2), "]",
                                          "\nr(SB)=", round((2*cor.test(data$acc_odd2, data$acc_even2)$estimate)/(1+cor.test(data$acc_odd2, data$acc_even2)$estimate), digits=2), 
                                          "[",round((2*cor.test(data$acc_odd2, data$acc_even2)$conf.int[1])/(1+cor.test(data$acc_odd2, data$acc_even2)$conf.int[1]),digits=2), "-",
                                          round((2*cor.test(data$acc_odd2, data$acc_even2)$conf.int[2])/(1+cor.test(data$acc_odd2, data$acc_even2)$conf.int[2]),digits=2), "]",
                                          sep=""),
                           guide = "legend")
    ggsave(filename = "figures/Behavioural/WO/accuracy_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')

    
# Perseveration----
  # Means
    mean_per1<-vector();mean_per2<-vector();
    for (i in {unique(xdata$SubID)}){
      mean_per1[i]=mean(as.numeric(xdata[which(xdata$Session==1&xdata$SubID==i), ]$persev)-1, na.rm=T)
      mean_per2[i]=mean(as.numeric(xdata[which(xdata$Session==2&xdata$SubID==i), ]$persev)-1, na.rm=T)
    };
    r_mper<-cor.test(mean_per1,mean_per2)
    icca1_mper<-icc(cbind(mean_per1,mean_per2), model="twoway", type="agreement",unit="single")
    icc1_mper<-icc(cbind(mean_per1,mean_per2), model="oneway", type="consistency",unit="single")
    
  # Sessions separately  
    m_per_s1=glmer(persev~1+(1|SubID), data=xdata[which(xdata$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
      # predicted values & standard errors
      temp<-ggpredict(m_per_s1, terms=c("SubID[all]"), type="re")
      s_per1=temp$predicted
      s_per1_se=as.vector(unlist(se.ranef(m_per_s1)))
    m_per_s2=glmer(persev~1+(1|SubID), data=xdata[which(xdata$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
      # predicted values & standard errors
      temp<-ggpredict(m_per_s2, terms=c("SubID[all]"), type="re")
      s_per2=temp$predicted
      s_per2_se=as.vector(unlist(se.ranef(m_per_s2)))
    
    # Jointly
    m_per=glmer(persev~1+(1|SubID/Session), data=xdata, family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
      temp<-ggpredict(m_per, terms=c("SubID[all]", "Session"), type="re")
      per1=temp[temp$group==1,]$predicted
      per2=temp[temp$group==2,]$predicted
      per1_se=as.vector(unlist(se.ranef(m_per)[1])[1:150]+unlist(se.ranef(m_per)[2]))
      per2_se=as.vector(unlist(se.ranef(m_per)[1])[151:300]+unlist(se.ranef(m_per)[2]))
    
    # Plot
    data=data.frame(per1,per2,per1_se,per2_se,s_per1,s_per2,s_per1_se,s_per2_se)
    ggplot(data=data)+
      geom_point(aes(s_per1,s_per2, size=(s_per1_se+s_per2_se)/2),color='black', alpha=0.2)+
      geom_point(aes(s_per1,s_per2, color="lightgrey"))+
      geom_smooth(aes(s_per1,s_per2),color='lightgrey',method=lm,se=F)+
      geom_point(aes(per1,per2, size=(per1_se+per2_se)/2,color='indianred'), alpha=0.2)+
      geom_point(aes(per1,per2,color='darkred'))+
      geom_smooth(aes(per1,per2),color='darkred',method=lm,se=F)+
      labs(title = "Perseveration", x="Perseveration T1", y="Perseveration T2")+
      theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
            panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
            legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
      scale_color_identity(name="",breaks = c("lightgrey", "darkred", "indianred"),
                           labels = c( paste("Separate:\nICC(A,1)=",
                                             round(icc(cbind(s_per1,s_per2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                             "[", round(icc(cbind(s_per1,s_per2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                             "-",round(icc(cbind(s_per1,s_per2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                             "]\nICC(1)=",
                                             round(icc(cbind(s_per1,s_per2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                             "[", round(icc(cbind(s_per1,s_per2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                             "-",round(icc(cbind(s_per1,s_per2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                             "]\nr=",
                                             round(cor.test(s_per1, s_per2)$estimate,2),"[",round(cor.test(s_per1, s_per2)$conf.int[1],2),
                                             "-",round(cor.test(s_per1, s_per2)$conf.int[2],2),"]", sep=""),
                                       paste("Joint:\nICC(A,1)=",
                                             round(icc(cbind(per1,per2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                             "[", round(icc(cbind(per1,per2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                             "-",round(icc(cbind(per1,per2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                             "]\nICC(1)=",
                                             round(icc(cbind(per1,per2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                             "[", round(icc(cbind(per1,per2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                             "-",round(icc(cbind(per1,per2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                             "]\nr=",
                                             round(cor.test(per1, per2)$estimate,2),"[",round(cor.test(per1, per2)$conf.int[1],2),
                                             "-",round(cor.test(per1, per2)$conf.int[2],2),"]",sep=""),
                                       paste("Model-calculated:\nICC(1)=",
                                             round(get_variance_intercept(m_per)[2]/
                                                     (get_variance_intercept(m_per)[2]+
                                                        (get_variance_intercept(m_per)[1])),digits = 2),sep="")),
                           guide = "legend")+
      guides(size=F, alpha=T)
    ggsave(filename = "figures/Behavioural/WO/perseveration_r.png", width = 4.5, height = 4.5, units = 'in')
  
  # Split half
    m_per_odd_1=glmer(persev~1+(1|SubID), data=xdata_odd[which(xdata_odd$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    m_per_even_1=glmer(persev~1+(1|SubID), data=xdata_even[which(xdata_odd$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    m_per_odd_2=glmer(persev~1+(1|SubID), data=xdata_odd[which(xdata_odd$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    m_per_even_2=glmer(persev~1+(1|SubID), data=xdata_even[which(xdata_odd$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  
  #predicted values
    data=data.frame(per_odd1=as.vector(t(inv.logit(coef(m_per_odd_1)$SubID[,"(Intercept)"]))),
                    per_even1=as.vector(t(inv.logit(coef(m_per_even_1)$SubID[,"(Intercept)"]))),
                    per_odd2=as.vector(t(inv.logit(coef(m_per_odd_2)$SubID[,"(Intercept)"]))),
                    per_even2=as.vector(t(inv.logit(coef(m_per_even_2)$SubID[,"(Intercept)"]))))
    
  #plot
    ggplot(data=data,aes(per_odd2,per_even2,color='darkred'))+
      geom_point(color='darkred')+
      geom_smooth(method=lm,se=F)+
      labs(title = "Perseveration", x="Perseveration Odd Trials", y="Perseveration Even Trials")+
      theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
            panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
            legend.position = c(0.25, 0.95),legend.background=element_blank())+
      scale_color_identity(name="",breaks = "darkred",
                           labels = paste("r=",round(cor.test(data$per_odd2, data$per_even2)$estimate,digits=2), "[",round(cor.test(data$per_odd2, data$per_even2)$conf.int[1],digits=2), "-",
                                          round(cor.test(data$per_odd2, data$per_even2)$conf.int[2],digits=2), "]",
                                          "\nr(SB)=", round((2*cor.test(data$per_odd2, data$per_even2)$estimate)/(1+cor.test(data$per_odd2, data$per_even2)$estimate), digits=2), 
                                          "[",round((2*cor.test(data$per_odd2, data$per_even2)$conf.int[1])/(1+cor.test(data$per_odd2, data$per_even2)$conf.int[1]),digits=2), "-",
                                          round((2*cor.test(data$per_odd2, data$per_even2)$conf.int[2])/(1+cor.test(data$per_odd2, data$per_even2)$conf.int[2]),digits=2), "]",
                                          sep=""),
                           guide = "legend")
    ggsave(filename = "figures/Behavioural/WO/perseveration_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')

    
# Switching----
  # Means
  mean_stay1<-vector();mean_stay2<-vector();mean_stayp1<-vector();mean_stayp2<-vector();mean_stayn1<-vector();mean_stayn2<-vector();
  for (i in {unique(xdata$SubID)}){
    mean_stay1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i), ]$stay, na.rm=T)
    mean_stay2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i), ]$stay, na.rm=T)
    mean_stayp1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i&xdata$pfb==1), ]$stay, na.rm=T)
    mean_stayp2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i&xdata$pfb==1), ]$stay, na.rm=T)
    mean_stayn1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i&xdata$pfb==-1), ]$stay, na.rm=T)
    mean_stayn2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i&xdata$pfb==-1), ]$stay, na.rm=T)
  };
    r_mstay<-cor.test(mean_stay1,mean_stay2)
    icca1_mstay<-icc(cbind(mean_stay1,mean_stay2), model="twoway", type="agreement",unit="single")
    icc1_mstay<-icc(cbind(mean_stay1,mean_stay2), model="oneway", type="consistency",unit="single")
    r_mstayp<-cor.test(mean_stayp1,mean_stayp2)
    icca1_mstayp<-icc(cbind(mean_stayp1,mean_stayp2), model="twoway", type="agreement",unit="single")
    icc1_mstayp<-icc(cbind(mean_stayp1,mean_stayp2), model="oneway", type="consistency",unit="single")
    r_mstayn<-cor.test(mean_stayn1,mean_stayn2)
    icca1_mstayn<-icc(cbind(mean_stayn1,mean_stayn2), model="twoway", type="agreement",unit="single")
    icc1_mstayn<-icc(cbind(mean_stayn1,mean_stayn2), model="oneway", type="consistency",unit="single")
    
  #Separately
  m_sw_s1=glmer(stay~1+pfb+(1+pfb|SubID), data=xdata[which(xdata$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    s_stay1=as.vector(t(inv.logit(coef(m_sw_s1)$SubID[,"(Intercept)"])))
    s_stay1_se=as.vector(unlist(se.ranef(m_sw_s1))[1:150])
  m_sw_s2=glmer(stay~1+pfb+(1+pfb|SubID), data=xdata[which(xdata$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    s_stay2=as.vector(t(inv.logit(coef(m_sw_s2)$SubID[,"(Intercept)"])))
    s_stay2_se=as.vector(unlist(se.ranef(m_sw_s2))[1:150])
  # previous feedback as factor in order to get "simple effects" of staying after losses/wins for model-calculated ICC(1)
  m_sw_l_s1=glmer(stay~as.factor(pfb)+(1+as.factor(pfb)|SubID), data=xdata[which(xdata$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    s_stayn1=as.vector(t(inv.logit(coef(m_sw_l_s1)$SubID[,"(Intercept)"])))
    s_stayn1_se=as.vector(unlist(se.ranef(m_sw_l_s1))[1:150])
  m_sw_w_s1=glmer(stay~relevel(as.factor(pfb),"1")+(1+relevel(as.factor(pfb),"1")|SubID), data=xdata[which(xdata$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    s_stayp1=as.vector(t(inv.logit(coef(m_sw_w_s1)$SubID[,"(Intercept)"])))
    s_stayp1_se=as.vector(unlist(se.ranef(m_sw_w_s1))[1:150])
  m_sw_l_s2=glmer(stay~as.factor(pfb)+(1+as.factor(pfb)|SubID), data=xdata[which(xdata$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    s_stayn2=as.vector(t(inv.logit(coef(m_sw_l_s2)$SubID[,"(Intercept)"])))
    s_stayn2_se=as.vector(unlist(se.ranef(m_sw_l_s2))[1:150])
  m_sw_w_s2=glmer(stay~relevel(as.factor(pfb),"1")+(1+relevel(as.factor(pfb),"1")|SubID), data=xdata[which(xdata$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    s_stayp2=as.vector(t(inv.logit(coef(m_sw_w_s2)$SubID[,"(Intercept)"])))
    s_stayp2_se=as.vector(unlist(se.ranef(m_sw_w_s2))[1:150])
  
  # Jointly
  m_sw=glmer(stay~pfb+(1+pfb|SubID/Session), data=xdata, family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    temp<-ggpredict(m_sw, terms=c("SubID[all]", "Session"), type="re")
    stay1=temp[temp$group==1,]$predicted
    stay2=temp[temp$group==2,]$predicted
    stay1_se=as.vector(unlist(se.ranef(m_sw)[1])[1:150]+unlist(se.ranef(m_sw)[2])[1:150])
    stay2_se=as.vector(unlist(se.ranef(m_sw)[1])[151:300]+unlist(se.ranef(m_sw)[2])[1:150])
  
  # previous feedback as factor in order to get "simple effects" of staying after losses/wins for model-calculated ICC(1)
  m_sw_l=glmer(stay~as.factor(pfb)+(1+as.factor(pfb)|SubID/Session), data=xdata, family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    # predicted values & standard errors
    temp<-ggpredict(m_sw_l, terms=c("SubID[all]", "Session", "pfb"), type="re")
    stayn1=temp[temp$group==1 & temp$facet==-1,]$predicted
    stayn2=temp[temp$group==2 & temp$facet==-1,]$predicted
    stayn1_se=as.vector(unlist(se.ranef(m_sw_l)[1])[1:150]+unlist(se.ranef(m_sw_l)[2])[1:150])
    stayn2_se=as.vector(unlist(se.ranef(m_sw_l)[1])[151:300]+unlist(se.ranef(m_sw_l)[2])[1:150])
  m_sw_w=glmer(stay~relevel(as.factor(pfb),"1")+(1+relevel(as.factor(pfb),"1")|SubID/Session), data=xdata, family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
    temp<-ggpredict(m_sw_w, terms=c("SubID[all]", "Session", "pfb"), type="re")
    stayp1=temp[temp$group==1 & temp$facet==1,]$predicted
    stayp2=temp[temp$group==2 & temp$facet==1,]$predicted
    stayp1_se=as.vector(unlist(se.ranef(m_sw_w)[1])[1:150]+unlist(se.ranef(m_sw_w)[2])[1:150])
    stayp2_se=as.vector(unlist(se.ranef(m_sw_w)[1])[151:300]+unlist(se.ranef(m_sw_w)[2])[1:150])
    
# Plot
  # overall
  data=data.frame(stay1,stay2,stay1_se,stay2_se,s_stay1,s_stay2,s_stay1_se,s_stay2_se)
  ggplot(data=data)+
    geom_point(aes(s_stay1,s_stay2, size=(s_stay1_se+s_stay2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_stay1,s_stay2, color="lightgrey"))+
    geom_smooth(aes(s_stay1,s_stay2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(stay1,stay2, size=(stay1_se+stay2_se)/2,color='lightpink'), alpha=0.2)+
    geom_point(aes(stay1,stay2,color='maroon'))+
    geom_smooth(aes(stay1,stay2),color='maroon',method=lm,se=F)+
    labs(title = "Stay", x="Stay T1", y="Stay T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "maroon", "lightpink"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_stay1,s_stay2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_stay1,s_stay2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_stay1,s_stay2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_stay1,s_stay2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_stay1,s_stay2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_stay1,s_stay2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_stay1, s_stay2)$estimate,2),"[",round(cor.test(s_stay1, s_stay2)$conf.int[1],2),
                                           "-",round(cor.test(s_stay1, s_stay2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(stay1,stay2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(stay1,stay2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(stay1,stay2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(stay1,stay2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(stay1,stay2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(stay1,stay2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(stay1, stay2)$estimate,2),"[",round(cor.test(stay1, stay2)$conf.int[1],2),
                                           "-",round(cor.test(stay1, stay2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_intercept(m_sw)[2]/
                                                   (get_variance_intercept(m_sw)[2]+
                                                      (get_variance_intercept(m_sw)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/stay_r.png", width = 4.5, height = 4.5, units = 'in')
  
  #after losses
  data=data.frame(stayn1,stayn2,stayn1_se,stayn2_se,s_stayn1,s_stayn2,s_stayn1_se,s_stayn2_se)
  ggplot(data=data)+
    geom_point(aes(s_stayn1,s_stayn2, size=(s_stayn1_se+s_stayn2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_stayn1,s_stayn2, color="lightgrey"))+
    geom_smooth(aes(s_stayn1,s_stayn2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(stayn1,stayn2, size=(stayn1_se+stayn2_se)/2,color='pink'), alpha=0.2)+
    geom_point(aes(stayn1,stayn2,color='deeppink4'))+
    geom_smooth(aes(stayn1,stayn2),color='deeppink4',method=lm,se=F)+
    labs(title = "Lose:Stay", x="Lose:Stay T1", y="Lose:Stay T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "deeppink4", "pink"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_stayn1,s_stayn2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_stayn1,s_stayn2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_stayn1,s_stayn2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_stayn1,s_stayn2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_stayn1,s_stayn2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_stayn1,s_stayn2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_stayn1, s_stayn2)$estimate,2),"[",round(cor.test(s_stayn1, s_stayn2)$conf.int[1],2),
                                           "-",round(cor.test(s_stayn1, s_stayn2)$conf.int[2],2),"]", sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(stayn1,stayn2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(stayn1,stayn2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(stayn1,stayn2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(stayn1,stayn2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(stayn1,stayn2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(stayn1,stayn2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(stayn1, stayn2)$estimate,2),"[",round(cor.test(stayn1, stayn2)$conf.int[1],2),
                                           "-",round(cor.test(stayn1, stayn2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_intercept(m_sw_l)[2]/
                                                   (get_variance_intercept(m_sw_l)[2]+
                                                      (get_variance_intercept(m_sw_l)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/stayn_r.png", width = 4.5, height = 4.5, units = 'in')
  
  #after wins
  data=data.frame(stayp1,stayp2,stayp1_se,stayp2_se,s_stayp1,s_stayp2,s_stayp1_se,s_stayp2_se)
  ggplot(data=data)+
    geom_point(aes(s_stayp1,s_stayp2, size=(s_stayp1_se+s_stayp2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_stayp1,s_stayp2, color="lightgrey"))+
    geom_smooth(aes(s_stayp1,s_stayp2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(stayp1,stayp2, size=(stayp1_se+stayp2_se)/2,color='thistle'), alpha=0.2)+
    geom_point(aes(stayp1,stayp2,color='palevioletred'))+
    geom_smooth(aes(stayp1,stayp2),color='palevioletred',method=lm,se=F)+
    labs(title = "Win:Stay", x="Win:Stay T1", y="Win:Stay T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "palevioletred", "thistle"),
                         labels =c( paste("Separate:\nICC(A,1)=",
                                          round(icc(cbind(s_stayp1,s_stayp2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                          "[", round(icc(cbind(s_stayp1,s_stayp2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                          "-",round(icc(cbind(s_stayp1,s_stayp2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                          "]\nICC(1)=",
                                          round(icc(cbind(s_stayp1,s_stayp2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                          "[", round(icc(cbind(s_stayp1,s_stayp2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                          "-",round(icc(cbind(s_stayp1,s_stayp2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                          "]\nr=",
                                          round(cor.test(s_stayp1, s_stayp2)$estimate,2),"[",round(cor.test(s_stayp1, s_stayp2)$conf.int[1],2),
                                          "-",round(cor.test(s_stayp1, s_stayp2)$conf.int[2],2),"]",
                                          sep=""),
                                    paste("Joint:\nICC(A,1)=",
                                          round(icc(cbind(stayp1,stayp2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                          "[", round(icc(cbind(stayp1,stayp2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                          "-",round(icc(cbind(stayp1,stayp2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                          "]\nICC(1)=",
                                          round(icc(cbind(stayp1,stayp2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                          "[", round(icc(cbind(stayp1,stayp2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                          "-",round(icc(cbind(stayp1,stayp2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                          "]\nr=",
                                          round(cor.test(stayp1, stayp2)$estimate,2),"[",round(cor.test(stayp1, stayp2)$conf.int[1],2),
                                          "-",round(cor.test(stayp1, stayp2)$conf.int[2],2),"]",
                                          sep=""),
                                    paste("Model-calculated:\nICC(1)=",
                                          round(get_variance_intercept(m_sw_w)[2]/
                                                  (get_variance_intercept(m_sw_w)[2]+
                                                     (get_variance_intercept(m_sw_w)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/stayp_r.png", width = 4.5, height = 4.5, units = 'in')
  
  
# Split half
  m_sw_odd_1=glmer(stay~1+pfb+(1+pfb|SubID), data=xdata_odd[which(xdata_odd$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  m_sw_even_1=glmer(stay~1+pfb+(1+pfb|SubID), data=xdata_even[which(xdata_even$Session==1), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  m_sw_odd_2=glmer(stay~1+pfb+(1+pfb|SubID), data=xdata_odd[which(xdata_odd$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression
  m_sw_even_2=glmer(stay~1+pfb+(1+pfb|SubID), data=xdata_even[which(xdata_even$Session==2), ], family=binomial,control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)), na.action = na.exclude) #mixed logistic regression

  # plot 
    data=data.frame(stay_odd2=as.vector(t(inv.logit(coef(m_sw_odd_2)$SubID[,"(Intercept)"]))),
                    stay_even2=as.vector(t(inv.logit(coef(m_sw_even_2)$SubID[,"(Intercept)"]))),
                    stayp_odd2=as.vector(t(inv.logit(coef(m_sw_odd_2)$SubID[,"(Intercept)"]+coef(m_sw_odd_1)$SubID[,"pfb"]))),
                    stayp_even2=as.vector(t(inv.logit(coef(m_sw_even_2)$SubID[,"(Intercept)"]+coef(m_sw_even_1)$SubID[,"pfb"]))),
                    stayn_odd2=as.vector(t(inv.logit(coef(m_sw_odd_2)$SubID[,"(Intercept)"]-coef(m_sw_odd_1)$SubID[,"pfb"]))),
                    stayn_even2=as.vector(t(inv.logit(coef(m_sw_even_2)$SubID[,"(Intercept)"]-coef(m_sw_even_1)$SubID[,"pfb"]))))
                    
    ggplot(data=data,aes(stay_odd2,stay_even2,color='maroon'))+
      geom_point(color='maroon')+
      geom_smooth(method=lm,se=F)+
      labs(title = "Stay overall", x="Stay Odd Trials", y="Stay Even Trials")+
      theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
            panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
            legend.position = c(0.25, 0.95),legend.background=element_blank())+
      scale_color_identity(name="",breaks = "maroon",
                           labels = paste("r=",round(cor.test(data$stay_odd2, data$stay_even2)$estimate,digits=2),
                                          "[",round(cor.test(data$stay_odd2, data$stay_even2)$conf.int[1],digits=2), "-",
                                          round(cor.test(data$stay_odd2, data$stay_even2)$conf.int[2],digits=2), "]",
                                          "\nr(SB)=", round((2*cor.test(data$stay_odd2, data$stay_even2)$estimate)/
                                                              (1+cor.test(data$stay_odd2, data$stay_even2)$estimate), digits=2), 
                                          "[",round((2*cor.test(data$stay_odd2, data$stay_even2)$conf.int[1])/
                                                      (1+cor.test(data$stay_odd2, data$stay_even2)$conf.int[1]),digits=2), "-",
                                          round((2*cor.test(data$stay_odd2, data$stay_even2)$conf.int[2])/
                                                  (1+cor.test(data$stay_odd2, data$stay_even2)$conf.int[2]),digits=2), "]",
                                          sep=""),
                           guide = "legend")
    ggsave(filename = "figures/Behavioural/WO/stay_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')
    
    ggplot(data=data,aes(stayn_odd2,stayn_even2,color='deeppink4'))+
      geom_point(color='deeppink4')+
      geom_smooth(method=lm,se=F)+
      labs(title = "Lose: Stay", x="Lose: Stay Odd Trials", y="Lose: Stay Even Trials")+
      theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
            panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
            legend.position = c(0.25, 0.95),legend.background=element_blank())+
      scale_color_identity(name="",breaks = "deeppink4",
                           labels =  paste("r=",round(cor.test(data$stayn_odd2, data$stayn_even2)$estimate,digits=2),
                                                   "[",round(cor.test(data$stayn_odd2, data$stayn_even2)$conf.int[1],digits=2), "-",
                                                   round(cor.test(data$stayn_odd2, data$stayn_even2)$conf.int[2],digits=2), "]",
                                                   "\nr(SB)=", round((2*cor.test(data$stayn_odd2, data$stayn_even2)$estimate)/
                                                                       (1+cor.test(data$stayn_odd2, data$stayn_even2)$estimate), digits=2), 
                                                   "[",round((2*cor.test(data$stayn_odd2, data$stayn_even2)$conf.int[1])/
                                                               (1+cor.test(data$stayn_odd2, data$stayn_even2)$conf.int[1]),digits=2), "-",
                                                   round((2*cor.test(data$stayn_odd2, data$stayn_even2)$conf.int[2])/
                                                           (1+cor.test(data$stayn_odd2, data$stayn_even2)$conf.int[2]),digits=2), "]",
                                                   sep=""),
                           guide = "legend")
    ggsave(filename = "figures/Behavioural/WO/stayn_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')
    
    ggplot(data=data,aes(stayp_odd2,stayp_even2,color='palevioletred'))+
      geom_point(color='palevioletred')+
      geom_smooth(method=lm,se=F)+
      labs(title = "Win: Stay", x="Win: Stay Odd Trials", y="Win: Stay Even Trials")+
      theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
            panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
            legend.position = c(0.25, 0.95),legend.background=element_blank())+
      scale_color_identity(name="",breaks = "palevioletred",
                           labels = paste("r=",round(cor.test(data$stayp_odd2, data$stayp_even2)$estimate,digits=2),
                                          "[",round(cor.test(data$stayp_odd2, data$stayp_even2)$conf.int[1],digits=2), "-",
                                          round(cor.test(data$stayp_odd2, data$stayp_even2)$conf.int[2],digits=2), "]",
                                          "\nr(SB)=", round((2*cor.test(data$stayp_odd2, data$stayp_even2)$estimate)/
                                                              (1+cor.test(data$stayp_odd2, data$stayp_even2)$estimate), digits=2), 
                                          "[",round((2*cor.test(data$stayp_odd2, data$stayp_even2)$conf.int[1])/
                                                      (1+cor.test(data$stayp_odd2, data$stayp_even2)$conf.int[1]),digits=2), "-",
                                          round((2*cor.test(data$stayp_odd2, data$stayp_even2)$conf.int[2])/
                                                  (1+cor.test(data$stayp_odd2, data$stayp_even2)$conf.int[2]),digits=2), "]",
                                          sep=""),
                           guide = "legend")
    ggsave(filename = "figures/Behavioural/WO/stayp_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')


    
# RT----
  # Means
    mean_RT1<-vector();mean_RT2<-vector();mean_RTp1<-vector();mean_RTp2<-vector();mean_RTn1<-vector();mean_RTn2<-vector();  mean_deltaRT1<-vector();mean_deltaRT2<-vector();
    for (i in {unique(xdata$SubID)}){
      mean_RT1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i), ]$RT, na.rm=T)
      mean_RT2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i), ]$RT, na.rm=T)
      mean_RTp1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i&xdata$pfb==1), ]$RT, na.rm=T)
      mean_RTp2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i&xdata$pfb==1), ]$RT, na.rm=T)
      mean_RTn1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i&xdata$pfb==-1), ]$RT, na.rm=T)
      mean_RTn2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i&xdata$pfb==-1), ]$RT, na.rm=T)
      mean_deltaRT1[i]=mean(xdata[which(xdata$Session==1&xdata$SubID==i&xdata$pfb==1), ]$RT, na.rm=T)-
        mean(xdata[which(xdata$Session==1&xdata$SubID==i&xdata$pfb==-1), ]$RT, na.rm=T)    
      mean_deltaRT2[i]=mean(xdata[which(xdata$Session==2&xdata$SubID==i&xdata$pfb==1), ]$RT, na.rm=T)-
        mean(xdata[which(xdata$Session==2&xdata$SubID==i&xdata$pfb==-1), ]$RT, na.rm=T)
    };
    r_mRT<-cor.test(mean_RT1,mean_RT2)
    icca1_mRT<-icc(cbind(mean_RT1,mean_RT2), model="twoway", type="agreement",unit="single")
    icc1_mRT<-icc(cbind(mean_RT1,mean_RT2), model="oneway", type="consistency",unit="single")
    r_mRTp<-cor.test(mean_RTp1,mean_RTp2)
    icca1_mRTp<-icc(cbind(mean_RTp1,mean_RTp2), model="twoway", type="agreement",unit="single")
    icc1_mRTp<-icc(cbind(mean_RTp1,mean_RTp2), model="oneway", type="consistency",unit="single")
    r_mRTn<-cor.test(mean_RTn1,mean_RTn2)
    icca1_mRTn<-icc(cbind(mean_RTn1,mean_RTn2), model="twoway", type="agreement",unit="single")
    icc1_mRTn<-icc(cbind(mean_RTn1,mean_RTn2), model="oneway", type="consistency",unit="single")
    r_mdeltaRT<-cor.test(mean_deltaRT1,mean_deltaRT2)
    icca1_mdeltaRT<-icc(cbind(mean_deltaRT1,mean_deltaRT2), model="twoway", type="agreement",unit="single")
    icc1_mdeltaRT<-icc(cbind(mean_deltaRT1,mean_deltaRT2), model="oneway", type="consistency",unit="single")
    
# Separately
m_RT_s1=lmer(RT~pfb+(1+pfb|SubID), data=xdata[which(xdata$Session==1), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
    # predicted values & standard errors
    s_RT1=as.vector(t(coef(m_RT_s1)$SubID[,"(Intercept)"]))
    s_RT1_se=as.vector(unlist(se.ranef(m_RT_s1))[1:150])
    s_delta_RT1_se=as.vector(unlist(se.ranef(m_RT_s1))[151:300])
    temp<-ggpredict(m_RT_s1, terms=c("SubID[all]", "pfb"), type="re")
    s_delta_RT1=temp[temp$group==1,]$predicted-temp[temp$group==-1,]$predicted
    
m_RT_s2=lmer(RT~pfb+(1+pfb|SubID), data=xdata[which(xdata$Session==2), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
    # predicted values & standard errors
    s_RT2=as.vector(t(coef(m_RT_s2)$SubID[,"(Intercept)"]))
    s_RT2_se=as.vector(unlist(se.ranef(m_RT_s2))[1:150])
    s_delta_RT2_se=as.vector(unlist(se.ranef(m_RT_s2))[151:300])
    temp<-ggpredict(m_RT_s2, terms=c("SubID[all]", "pfb"), type="re")
    s_delta_RT2=temp[temp$group==1,]$predicted-temp[temp$group==-1,]$predicted
    
  # previous feedback as factor in order to get "simple effects" of staying after losses/wins for standard errors
  m_RT_l_s1=lmer(RT~as.factor(pfb)+(1+as.factor(pfb)|SubID), data=xdata[which(xdata$Session==1), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
      # predicted values & standard errors
      s_RTn1=as.vector(t(coef(m_RT_l_s1)$SubID[,"(Intercept)"]))
      s_RTn1_se=as.vector(unlist(se.ranef(m_RT_l_s1))[1:150])
      
  m_RT_l_s2=lmer(RT~as.factor(pfb)+(1+as.factor(pfb)|SubID), data=xdata[which(xdata$Session==2), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
      # predicted values & standard errors
      s_RTn2=as.vector(t(coef(m_RT_l_s2)$SubID[,"(Intercept)"]))
      s_RTn2_se=as.vector(unlist(se.ranef(m_RT_l_s2))[1:150])
      
  m_RT_w_s1=lmer(RT~relevel(as.factor(pfb),"1")+(1+relevel(as.factor(pfb),"1")|SubID), data=xdata[which(xdata$Session==1), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
      # predicted values & standard errors
      s_RTp1=as.vector(t(coef(m_RT_w_s1)$SubID[,"(Intercept)"]))
      s_RTp1_se=as.vector(unlist(se.ranef(m_RT_w_s1))[1:150])
      
  m_RT_w_s2=lmer(RT~relevel(as.factor(pfb),"1")+(1+relevel(as.factor(pfb),"1")|SubID), data=xdata[which(xdata$Session==2), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
      # predicted values & standard errors
      s_RTp2=as.vector(t(coef(m_RT_w_s2)$SubID[,"(Intercept)"]))
      s_RTp2_se=as.vector(unlist(se.ranef(m_RT_w_s2))[1:150])
      
    
# Jointly
m_RT=lmer(RT~pfb+(1+pfb|SubID/Session), data=xdata, na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))#mixed linear regression
  # predicted values & standard errors
  temp<-ggpredict(m_RT, terms=c("SubID[all]", "Session"), type="re")
  RT1=temp[temp$group==1,]$predicted
  RT2=temp[temp$group==2,]$predicted
  RT1_se=as.vector(unlist(se.ranef(m_RT)[1])[1:150]+unlist(se.ranef(m_RT)[2])[1:150])
  delta_RT1_se=as.vector(unlist(se.ranef(m_RT)[1])[77:114]+unlist(se.ranef(m_RT)[2])[151:300])
  RT2_se=as.vector(unlist(se.ranef(m_RT)[1])[151:300]+unlist(se.ranef(m_RT)[2])[1:150])
  delta_RT2_se=as.vector(unlist(se.ranef(m_RT)[1])[115:152]+unlist(se.ranef(m_RT)[2])[151:300])
  temp<-ggpredict(m_RT, terms=c("SubID[all]", "Session", "pfb"), type="re")
  delta_RT1=temp[temp$group==1 & temp$facet==1,]$predicted-temp[temp$group==1 & temp$facet==-1,]$predicted
  delta_RT2=temp[temp$group==2 & temp$facet==1,]$predicted-temp[temp$group==2 & temp$facet==-1,]$predicted
  
m_RT_l=lmer(RT~as.factor(pfb)+(1+as.factor(pfb)|SubID/Session), data=xdata, na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))#mixed linear regression
  # predicted values & standard errors
  temp<-ggpredict(m_RT_l, terms=c("SubID[all]", "Session", "pfb"), type="re")
  RTn1=temp[temp$group==1 & temp$facet==-1,]$predicted
  RTn2=temp[temp$group==2 & temp$facet==-1,]$predicted
  RTn1_se=as.vector(unlist(se.ranef(m_RT_l)[1])[1:150]+unlist(se.ranef(m_RT_l)[2])[1:150])
  RTn2_se=as.vector(unlist(se.ranef(m_RT_l)[1])[151:300]+unlist(se.ranef(m_RT_l)[2])[1:150])

m_RT_w=lmer(RT~relevel(as.factor(pfb),"1")+(1+relevel(as.factor(pfb),"1")|SubID/Session), data=xdata, na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5)))#mixed linear regression
  # predicted values & standard errors
  temp<-ggpredict(m_RT_w, terms=c("SubID[all]", "Session", "pfb"), type="re")
  RTp1=temp[temp$group==1 & temp$facet==1,]$predicted
  RTp2=temp[temp$group==2 & temp$facet==1,]$predicted
  RTp1_se=as.vector(unlist(se.ranef(m_RT_w)[1])[1:150]+unlist(se.ranef(m_RT_w)[2])[1:150])
  RTp2_se=as.vector(unlist(se.ranef(m_RT_w)[1])[151:300]+unlist(se.ranef(m_RT_w)[2])[1:150])

# Plot
  # overall
  data=data.frame(RT1,RT2,RT1_se,RT2_se,s_RT1,s_RT2,s_RT1_se,s_RT2_se)
  ggplot(data=data)+
    geom_point(aes(s_RT1,s_RT2, size=(s_RT1_se+s_RT2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_RT1,s_RT2, color="lightgrey"))+
    geom_smooth(aes(s_RT1,s_RT2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(RT1,RT2, size=(RT1_se+RT2_se)/2,color='slategray2'), alpha=0.2)+
    geom_point(aes(RT1,RT2,color='skyblue2'))+
    geom_smooth(aes(RT1,RT2),color='skyblue2',method=lm,se=F)+
    labs(title = "RT", x="RT T1", y="RT T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "skyblue2", "slategray2"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_RT1,s_RT2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_RT1,s_RT2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_RT1,s_RT2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_RT1,s_RT2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_RT1,s_RT2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_RT1,s_RT2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_RT1, s_RT2)$estimate,2),"[",round(cor.test(s_RT1, s_RT2)$conf.int[1],2),
                                           "-",round(cor.test(s_RT1, s_RT2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(RT1,RT2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(RT1,RT2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(RT1,RT2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(RT1,RT2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(RT1,RT2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(RT1,RT2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(RT1, RT2)$estimate,2),"[",round(cor.test(RT1, RT2)$conf.int[1],2),
                                           "-",round(cor.test(RT1, RT2)$conf.int[2],2),"]",sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_intercept(m_RT)[2]/
                                                   (get_variance_intercept(m_RT)[2]+
                                                      (get_variance_intercept(m_RT)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/RT_r.png", width = 4.5, height = 4.5, units = 'in')
  
  #after losses
  data=data.frame(RTn1,RTn2,RTn1_se,RTn2_se,s_RTn1,s_RTn2,s_RTn1_se,s_RTn2_se)
  ggplot(data=data)+
    geom_point(aes(s_RTn1,s_RTn2, size=(s_RTn1_se+s_RTn2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_RTn1,s_RTn2, color="lightgrey"))+
    geom_smooth(aes(s_RTn1,s_RTn2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(RTn1,RTn2, size=(RTn1_se+RTn2_se)/2,color='slategray'), alpha=0.2)+
    geom_point(aes(RTn1,RTn2,color='skyblue4'))+
    geom_smooth(aes(RTn1,RTn2),color='skyblue4',method=lm,se=F)+
    labs(title = "Lose:RT", x="Lose:RT T1", y="Lose:RT T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "skyblue4", "slategray"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_RT1,s_RTn2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_RTn1,s_RTn2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_RTn1,s_RTn2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_RTn1,s_RTn2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_RTn1,s_RTn2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_RTn1,s_RTn2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_RTn1, s_RTn2)$estimate,2),"[",round(cor.test(s_RTn1, s_RTn2)$conf.int[1],2),
                                           "-",round(cor.test(s_RTn1, s_RTn2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(RTn1,RTn2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(RTn1,RTn2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(RTn1,RTn2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(RTn1,RTn2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(RTn1,RTn2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(RTn1,RTn2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(RTn1, RTn2)$estimate,2),"[",round(cor.test(RTn1, RTn2)$conf.int[1],2),
                                           "-",round(cor.test(RTn1, RTn2)$conf.int[2],2),"]",sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_intercept(m_RT_l)[2]/
                                                   (get_variance_intercept(m_RT_l)[2]+
                                                      (get_variance_intercept(m_RT_l)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/RTn_r.png", width = 4.5, height = 4.5, units = 'in')
  
  #after wins
  data=data.frame(RTp1,RTp2,RTp1_se,RTp2_se,s_RTp1,s_RTp2,s_RTp1_se,s_RTp2_se)
  ggplot(data=data)+
    geom_point(aes(s_RTp1,s_RTp2, size=(s_RTp1_se+s_RTp2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_RTp1,s_RTp2, color="lightgrey"))+
    geom_smooth(aes(s_RTp1,s_RTp2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(RTp1,RTp2, size=(RTp1_se+RTp2_se)/2,color='lightsteelblue'), alpha=0.2)+
    geom_point(aes(RTp1,RTp2,color='steelblue'))+
    geom_smooth(aes(RTp1,RTp2),color='steelblue',method=lm,se=F)+
    labs(title = "Win:RT", x="Win:RT T1", y="Win:RT T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "steelblue", "lightsteelblue"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_RT1,s_RTp2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_RTp1,s_RTp2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_RTp1,s_RTp2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_RTp1,s_RTp2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_RTp1,s_RTp2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_RTp1,s_RTp2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_RTp1, s_RTp2)$estimate,2),"[",round(cor.test(s_RTp1, s_RTp2)$conf.int[1],2),
                                           "-",round(cor.test(s_RTp1, s_RTp2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(RTp1,RTp2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(RTp1,RTp2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(RTp1,RTp2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(RTp1,RTp2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(RTp1,RTp2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(RTp1,RTp2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(RTp1, RTp2)$estimate,2),"[",round(cor.test(RTp1, RTp2)$conf.int[1],2),
                                           "-",round(cor.test(RTp1, RTp2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_intercept(m_RT_w)[2]/
                                                   (get_variance_intercept(m_RT_w)[2]+
                                                      (get_variance_intercept(m_RT_w)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/RTp_r.png", width = 4.5, height = 4.5, units = 'in')
  
  #delta RT
  data=data.frame(delta_RT1,delta_RT2,delta_RT1_se,delta_RT2_se,s_delta_RT1,s_delta_RT2,s_delta_RT1_se,s_delta_RT2_se)
  ggplot(data=data)+
    geom_point(aes(s_delta_RT1,s_delta_RT2, size=(s_delta_RT1_se+s_delta_RT2_se)/2),color='black', alpha=0.2)+
    geom_point(aes(s_delta_RT1,s_delta_RT2, color="lightgrey"))+
    geom_smooth(aes(s_delta_RT1,s_delta_RT2),color='lightgrey',method=lm,se=F)+
    geom_point(aes(delta_RT1,delta_RT2, size=(delta_RT1_se+delta_RT2_se)/2,color='cornflowerblue'), alpha=0.2)+
    geom_point(aes(delta_RT1,delta_RT2,color='midnightblue'))+
    geom_smooth(aes(delta_RT1,delta_RT2),color='midnightblue',method=lm,se=F)+
    labs(title = "Win RT - Loss RT", x="Win RT - Loss RT T1", y="Win RT - Loss RT T2")+
    theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
          panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
          legend.position = c(0.25, 0.90), legend.background=element_blank(), legend.key=element_rect(color=NA, fill=NA))+
    scale_color_identity(name="",breaks = c("lightgrey", "midnightblue", "cornflowerblue"),
                         labels = c( paste("Separate:\nICC(A,1)=",
                                           round(icc(cbind(s_delta_RT1,s_delta_RT2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_delta_RT1,s_delta_RT2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_delta_RT1,s_delta_RT2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(s_delta_RT1,s_delta_RT2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(s_delta_RT1,s_delta_RT2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(s_delta_RT1,s_delta_RT2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(s_delta_RT1, s_delta_RT2)$estimate,2),"[",round(cor.test(s_delta_RT1, s_delta_RT2)$conf.int[1],2),
                                           "-",round(cor.test(s_delta_RT1, s_delta_RT2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Joint:\nICC(A,1)=",
                                           round(icc(cbind(delta_RT1,delta_RT2),model = "twoway",type="agreement",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(delta_RT1,delta_RT2),model = "twoway",type="agreement",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(delta_RT1,delta_RT2),model = "twoway",type="agreement",unit="single")$ubound,digits=2), 
                                           "]\nICC(1)=",
                                           round(icc(cbind(delta_RT1,delta_RT2),model = "oneway",type="consistency",unit="single")$value,digits=2),
                                           "[", round(icc(cbind(delta_RT1,delta_RT2),model = "oneway",type="consistency",unit="single")$lbound,digits=2),
                                           "-",round(icc(cbind(delta_RT1,delta_RT2),model = "oneway",type="consistency",unit="single")$ubound,digits=2), 
                                           "]\nr=",
                                           round(cor.test(delta_RT1, delta_RT2)$estimate,2),"[",round(cor.test(delta_RT1, delta_RT2)$conf.int[1],2),
                                           "-",round(cor.test(delta_RT1, delta_RT2)$conf.int[2],2),"]",
                                           sep=""),
                                     paste("Model-calculated:\nICC(1)=",
                                           round(get_variance_slope(m_RT)[2]/
                                                   (get_variance_slope(m_RT)[2]+
                                                      (get_variance_slope(m_RT)[1])),digits = 2),sep="")),
                         guide = "legend")+
    guides(size=F, alpha=T)
  ggsave(filename = "figures/Behavioural/WO/delta_RT_r.png", width = 4.5, height = 4.5, units = 'in')
  
  
# Split half
m_RT_odd_1=lmer(RT~pfb+(1+pfb|SubID), data=xdata_odd[which(xdata_odd$Session==1), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
m_RT_even_1=lmer(RT~pfb+(1+pfb|SubID), data=xdata_even[which(xdata_even$Session==1), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
m_RT_odd_2=lmer(RT~pfb+(1+pfb|SubID), data=xdata_odd[which(xdata_odd$Session==2), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression
m_RT_even_2=lmer(RT~pfb+(1+pfb|SubID), data=xdata_even[which(xdata_even$Session==2), ], na.action = na.exclude, control=lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1e5))) #mixed linear regression

# plot
RT_odd2=as.vector(t(coef(m_RT_odd_2)$SubID[,"(Intercept)"]))
RT_even2=as.vector(t(coef(m_RT_even_2)$SubID[,"(Intercept)"]))
RTp_odd2=as.vector(t(coef(m_RT_odd_2)$SubID[,"(Intercept)"]+coef(m_RT_odd_2)$SubID[,"pfb"]))
RTp_even2=as.vector(t(coef(m_RT_even_2)$SubID[,"(Intercept)"]+coef(m_RT_even_2)$SubID[,"pfb"]))
RTn_odd2=as.vector(t(coef(m_RT_odd_2)$SubID[,"(Intercept)"]-coef(m_RT_odd_2)$SubID[,"pfb"]))
RTn_even2=as.vector(t(coef(m_RT_even_2)$SubID[,"(Intercept)"]-coef(m_RT_even_2)$SubID[,"pfb"]))
delta_RT_odd2=RTp_odd2-RTn_odd2
delta_RT_even2=RTp_even2-RTn_even2
data=data.frame(RT_odd2,RT_even2,RTp_odd2,RTp_even2,RTn_odd2,RTn_even2, delta_RT_odd2, delta_RT_even2)

ggplot(data=data,aes(RT_odd2,RT_even2,color='skyblue2'))+
  geom_point(color='skyblue2')+
  geom_smooth(method=lm,se=F)+
  labs(title = "Reaction Times", x="RT Odd Trials", y="RT Even Trials")+
  theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
        panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
        legend.position = c(0.25, 0.95),legend.background=element_blank())+
  scale_color_identity(name="",breaks = "skyblue2",
                       labels = paste("r=",round(cor.test(data$RT_odd2, data$RT_even2)$estimate,digits=2),
                                      "[",round(cor.test(data$RT_odd2, data$RT_even2)$conf.int[1],digits=2), "-",
                                      round(cor.test(data$RT_odd2, data$RT_even2)$conf.int[2],digits=2), "]",
                                      "\nr(SB)=", round((2*cor.test(data$RT_odd2, data$RT_even2)$estimate)/
                                                          (1+cor.test(data$RT_odd2, data$RT_even2)$estimate), digits=2), 
                                      "[",round((2*cor.test(data$RT_odd2, data$RT_even2)$conf.int[1])/
                                                  (1+cor.test(data$RT_odd2, data$RT_even2)$conf.int[1]),digits=2), "-",
                                      round((2*cor.test(data$RT_odd2, data$RT_even2)$conf.int[2])/
                                              (1+cor.test(data$RT_odd2, data$RT_even2)$conf.int[2]),digits=2), "]",
                                      sep=""),
                       guide = "legend")
ggsave(filename = "figures/Behavioural/WO/RT_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')

ggplot(data=data,aes(RTn_odd2,RTn_even2,color='skyblue4'))+
  geom_point(color='skyblue4')+
  geom_smooth(method=lm,se=F)+
  labs(title = "Lose: Reaction Times", x="Lose: RT Odd Trials", y="Lose: RT Even Trials")+
  theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
        panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
        legend.position = c(0.25, 0.95),legend.background=element_blank())+
  scale_color_identity(name="",breaks = "skyblue4",
                       labels = paste("r=",round(cor.test(data$RTn_odd2, data$RTn_even2)$estimate,digits=2),
                                      "[",round(cor.test(data$RTn_odd2, data$RTn_even2)$conf.int[1],digits=2), "-",
                                      round(cor.test(data$RTn_odd2, data$RTn_even2)$conf.int[2],digits=2), "]",
                                      "\nr(SB)=", round((2*cor.test(data$RTn_odd2, data$RTn_even2)$estimate)/
                                                          (1+cor.test(data$RTn_odd2, data$RTn_even2)$estimate), digits=2), 
                                      "[",round((2*cor.test(data$RTn_odd2, data$RTn_even2)$conf.int[1])/
                                                  (1+cor.test(data$RTn_odd2, data$RTn_even2)$conf.int[1]),digits=2), "-",
                                      round((2*cor.test(data$RTn_odd2, data$RTn_even2)$conf.int[2])/
                                              (1+cor.test(data$RTn_odd2, data$RTn_even2)$conf.int[2]),digits=2), "]",
                                      sep=""),
                       guide = "legend")
ggsave(filename = "figures/Behavioural/WO/RTn_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')

ggplot(data=data,aes(RTp_odd2,RTp_even2,color='steelblue'))+
  geom_point(color='steelblue')+
  geom_smooth(method=lm,se=F)+
  labs(title = "Win: Reaction Times", x="Win: RT Odd Trials", y="Win: RT Even Trials")+
  theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
        panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
        legend.position = c(0.25, 0.95),legend.background=element_blank())+
  scale_color_identity(name="",breaks = "steelblue",
                       labels = paste("r=",round(cor.test(data$RTp_odd2, data$RTp_even2)$estimate,digits=2),
                                      "[",round(cor.test(data$RTp_odd2, data$RTp_even2)$conf.int[1],digits=2), "-",
                                      round(cor.test(data$RTp_odd2, data$RTp_even2)$conf.int[2],digits=2), "]",
                                      "\nr(SB)=", round((2*cor.test(data$RTp_odd2, data$RTp_even2)$estimate)/
                                                          (1+cor.test(data$RTp_odd2, data$RTp_even2)$estimate), digits=2), 
                                      "[",round((2*cor.test(data$RTp_odd2, data$RTp_even2)$conf.int[1])/
                                                  (1+cor.test(data$RTp_odd2, data$RTp_even2)$conf.int[1]),digits=2), "-",
                                      round((2*cor.test(data$RTp_odd2, data$RTp_even2)$conf.int[2])/
                                              (1+cor.test(data$RTp_odd2, data$RTp_even2)$conf.int[2]),digits=2), "]",
                                      sep=""),
                       guide = "legend")
ggsave(filename = "figures/Behavioural/WO/RTp_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')

ggplot(data=data,aes(delta_RT_odd2,delta_RT_even2,color='midnightblue'))+
  geom_point(color='midnightblue')+
  geom_smooth(method=lm,se=F)+
  labs(title = "Difference between Reaction Times \n after Wins and Losses", x="Win RT - Loss RT T1", y="Win RT - Loss RT T2")+
  theme(text=element_text(family="Futura Bk BT"),plot.title = element_text(hjust = 0.5,face = "bold"), 
        panel.background = element_blank(), axis.line = element_line(colour = "black", size=0.2),
        legend.position = c(0.25, 0.95),legend.background=element_blank())+
  scale_color_identity(name="",breaks = "midnightblue",
                       labels = paste("r=",round(cor.test(data$delta_RT_odd2, data$delta_RT_even2)$estimate,digits=2),
                                      "[",round(cor.test(data$delta_RT_odd2, data$delta_RT_even2)$conf.int[1],digits=2), "-",
                                      round(cor.test(data$delta_RT_odd2, data$delta_RT_even2)$conf.int[2],digits=2), "]",
                                      "\nr(SB)=", round((2*cor.test(data$delta_RT_odd2, data$delta_RT_even2)$estimate)/
                                                          (1+cor.test(data$delta_RT_odd2, data$delta_RT_even2)$estimate), digits=2), 
                                      "[",round((2*cor.test(data$delta_RT_odd2, data$delta_RT_even2)$conf.int[1])/
                                                  (1+cor.test(data$delta_RT_odd2, data$delta_RT_even2)$conf.int[1]),digits=2), "-",
                                      round((2*cor.test(data$delta_RT_odd2, data$delta_RT_even2)$conf.int[2])/
                                              (1+cor.test(data$delta_RT_odd2, data$delta_RT_even2)$conf.int[2]),digits=2), "]",
                                      sep=""),
                       guide = "legend")
ggsave(filename = "figures/Behavioural/WO/RT_delta_splithalf_ses2_r.png", width = 4.5, height = 4.5, units = 'in')


# Make little plot to show changing variance components wrt ICC with estimation methods ----

# For reference: Formula for ICC(A,1)
# ICCA1<-(MSr - MSe)/(MSr + (nr - 1) * MSe +  (nr/ns) * (MSc - MSe)
# ICC1<-(MSr-MSw)/(MSr+ (nr-1)*MSw)

# Prep
MSr<-vector()
MSc<-vector()
MSe<-vector()
g<-vector()


namesmean=matrix(c("mean_acc1", "mean_acc2",
                   "mean_per1", "mean_per2",
                   "mean_stay1", "mean_stay2",
                   "mean_stayp1", "mean_stayp2",
                   "mean_stayn1", "mean_stayn2",
                   "mean_RT1", "mean_RT2",
                   "mean_RTp1", "mean_RTp2",
                   "mean_RTn1", "mean_RTn2",
                   "mean_deltaRT1", "mean_deltaRT2"),
                 nrow=9, ncol=2, byrow=T)

namessep=matrix(c("s_acc1", "s_acc2",
                  "s_per1", "s_per2",
                  "s_stay1", "s_stay2",
                  "s_stayp1", "s_stayp2",
                  "s_stayn1", "s_stayn2",
                  "s_RT1", "s_RT2",
                  "s_RTp1", "s_RTp2",
                  "s_RTn1", "s_RTn2",
                  "s_delta_RT1", "s_delta_RT2"),
                nrow=9, ncol=2, byrow=T)

namesjoint=matrix(c("acc1", "acc2",
                    "per1", "per2",
                    "stay1", "stay2",
                    "stayp1", "stayp2",
                    "stayn1", "stayn2",
                    "RT1", "RT2",
                    "RTp1", "RTp2",
                    "RTn1", "RTn2",
                    "delta_RT1", "delta_RT2"),
                  nrow=9, ncol=2, byrow=T)

namesmodelc=c("m_ac","m_per","m_sw","m_sw_w","m_sw_l", "m_RT", "m_RT_w", "m_RT_l", "m_RT")

namestitle=c("Accuracy", "Perseveration", "Stay behaviour overall", "Staying after wins", "Staying after losses",
             "Reaction times overall", "Reaction times after wins", "Reaction times after losses",
             "∆ reaction times")

# j is the different graphs (Accuracy, Perseveration, etc)
for (j in 1:9){
  # i is the different estimation methods (mean, separate models, joint model, Model calculated)?
  for (i in 1:4)
  {
    if (any(i==1:3)){
      
      # Bind data to ratings depending on different values of i and j 
      # 1 = mean
      if (i==1){ratings=cbind(eval(parse(text=namesmean[j,1])),eval(parse(text=namesmean[j,2])))}
      # 2 = separate
      else if (i==2){ratings=cbind(eval(parse(text=namessep[j,1])),eval(parse(text=namessep[j,2])))}
      # 3 = joint
      else {ratings=cbind(eval(parse(text=namesjoint[j,1])),eval(parse(text=namesjoint[j,2])))}
      
      # logit values for first 5 graphs
      if (any(j==1:5)){ratings<-logit(ratings)}
      
      ratings[!is.finite(ratings)]=NA #remove infinity vals
      ratings <- as.matrix(na.omit(ratings)) # remove NAs
      
      ns <- nrow(ratings) # Number of rows
      nr <- ncol(ratings) # Number of columns
      
      SStotal <- var(as.numeric(ratings)) * (ns * nr - 1)
      MSr[i] <- var(apply(ratings, 1, mean)) * nr # Between subs variance
      
      # Within subs variance - This appears to be calculated and discarded
      MSw <- sum(apply(ratings, 1, var)/ns)  
      
      MSc[i] <- var(apply(ratings, 2, mean)) * ns # Session variance
      MSe[i] <- (SStotal - MSr[i] * (ns - 1) - MSc[i] * (nr - 1))/((ns - 1) * (nr - 1)) #Error variance
    }
    else{ # 4 = Model calculated
      # icc(1) stuff here
      MSc[i]=0
      if (any(j==1:8)){
        MSe[i]=? (eval(parse(text=namesmodelc[j])))[1]
        MSr[i]=get_variance_intercept(eval(parse(text=namesmodelc[j])))[2]}
      else {
        MSe[i]=get_variance_slope(eval(parse(text=namesmodelc[j])))[1]
        MSr[i]=get_variance_slope(eval(parse(text=namesmodelc[j])))[2]}
    }
  }
  
  x<-rowSums(cbind(MSr, MSc, MSe)) # Sum variance components
  value<-c(cbind(MSr, MSc, MSe)/x)   # Normalise (sum to 1)
  
  # Generate labels for the data frame below (y_data)
  varcomp<-c(rep("Between subject variance",4),rep("Within subject variance",4),rep("Error variance",4))
  model<-c(rep(c("Mean", "Separate Models", "Joint Model", "Model Calculated"),3))
  
  # Build data frame with:
  #   Col 1: different models 
  #   Col 2: different variance components
  #   Col 3: the actual values for the combinations of models and variance components
  ydata<-data.frame(model,varcomp,value)
  
  # Convert Cols 1 and 2 to factors
  ydata$model<-factor(ydata$model,levels = c("Mean","Separate Models","Joint Model","Model Calculated"))
  ydata$varcomp<-factor(ydata$varcomp,levels = c("Within subject variance","Error variance","Between subject variance"))
  
  # Generate the plots and assign them to a variable called gN (e.g. g1, g2, etc.)
  # Plot for each measure (Accuracy, etc.)
  assign(
    paste("g",j,sep=""),
    ggplot(ydata, aes(fill=varcomp, y=value, x=model)) + 
           geom_bar(position="stack", stat="identity", width=0.7)+
           scale_fill_manual(values = c("#16176A", "#3E75A2","#72ADD7"))+
           labs(title = namestitle[j], y="% Variance", x="",element_text(size = 30))+
           theme(text = element_text(family="Futura Bk BT",size = 18),
                 plot.title = element_text(hjust = 0.5,face = "bold"), 
                 panel.background = element_blank(),
                 axis.line = element_line(colour = "black", size=0.2),
                 legend.position = "bottom",
                 legend.background = element_blank(),
                 legend.title = element_blank()) +
           coord_cartesian(expand=T)
  )
}

f<-ggarrange(g1, g2, g3, g4, g5, g6, g7, g8, g9, nrow = 3, ncol=3)
ggsave(filename = paste("figures/Behavioural/WO/","r_varcomps_rel.png", sep=""), width = 25, height = 15, units = 'in')

# Plots ----

## Accuracy ----

## Perseveration ----

## Switching ----

## RT ----



