library(TOSTER)
library(reshape2)
library(tidyverse)
library(ggplot2)
library(dplyr)
library(data.table)


# Load data for each n in our dataset
boot <- read.csv("relative_variance_bootstrap.csv")
#melt from wide to long
boot <- melt(boot, id.vars = c("variable","iteration","n","model"), variable.name = "varcomp")
boot$varcomp <- fct_rev(boot$varcomp) # reverse factor to be in line with other figures

# Set names for labelling figures
variable_names <- c("Reinforcement sensitivity for wins",
                    "Reinforcement sensitivity for losses",
                    "Learning rate")
estimation_method_names <- c("separate", "joint")

# for odd variable numbers, estimation method is separate, code 1, else estimation method is joint, code 2
boot$estimation_method <- case_when(boot$variable %in% c(1,3,5) ~ 1, 
                                    boot$variable %in% c(2,4,6) ~ 2)

boot$parameter <- case_when(      boot$variable %in% c(1,2) ~ 1, 
                                  boot$variable %in% c(3,4) ~ 2,
                                  boot$variable %in% c(5,6) ~ 3)


model_names <-c("ML", "MAP0", "EM")
variance_names <- c("within", "between", "error")
list <- lapply(1:length(variance_names), function(i){
  variance_names[i]
  list <- lapply(1:length(variable_names), function(ii){
    subdata <- subset(boot, parameter == ii & varcomp == variance_names[i])
    # set columns as factors
    factors <- c("n","model")
    subdata[factors] <- lapply(subdata[factors], factor)
    tmp <- aov(value ~ n * model * estimation_method, data = subdata)
    variable_names[ii]
    equ_anova(tmp, 0.06)
  })
  names(list) <- variable_names
  data.table::rbindlist(list, idcol ="variable")
})
names(list) <- variance_names
anovas_df <- data.table::rbindlist(list, idcol ="variance")
anovas_df$equiv_sign <- case_when(anovas_df$p.null < 0.05 & anovas_df$p.equ < 0.05 ~ "~",
                                  anovas_df$p.null >= 0.05 & anovas_df$p.equ < 0.05 ~ "=",
                                  anovas_df$p.null < 0.05 & anovas_df$p.equ >= 0.05 ~ sprintf("\u2731"),
                                  anovas_df$p.null >= 0.05 & anovas_df$p.equ >= 0.05 ~ "?")

anovas_df <- separate(anovas_df, "variable", c("variable", "estimation"), ": ")
anovas_df$estimation <- factor(anovas_df$estimation, levels = c("separate estimation", "joint estimation"), labels = c("Separate estimation", "Joint estimation"))
anovas_df$variance <- factor(anovas_df$variance, levels = variance_names, labels = c("Within-subject","Between-subject","Error"))
anovas_df$effect <- factor(anovas_df$effect, levels = unique(anovas_df$effect), 
                           labels = c("Sample size",
                                      "Model fitting approach",
                                      "Estimation method", 
                                      str_interp('Sample size ${sprintf("\u2731")} Model fitting approach'),
                                      str_interp('Sample size ${sprintf("\u2731")} Estimation method'),
                                      str_interp('Model fitting approach ${sprintf("\u2731")} Estimation method'),
                                      str_interp('Sample size ${sprintf("\u2731")} Model fitting approach ${sprintf("\u2731")} Estimation method')
                           ))

ggplot(anovas_df, aes(x=effect, y=variable, fill=pes)) +
  geom_raster() +
  geom_text(aes(label = equiv_sign), colour = "white", size = 6, fontface = "bold") +
  scale_fill_viridis_c(name = "Effect size") +
  facet_wrap("variance") +
  theme_minimal() +
  theme(text = element_text(size = 20), axis.title = element_blank()) +
  theme(legend.title = element_text(size = 16)) +
  theme(axis.text.x = element_text(angle = 270, hjust=0))
ggsave("parameter-anova-overview_figure.png", bg = "white", width=15, height=10)

       